#$Id$#

from books.model.Estimate import Estimate
from books.model.EstimateList import EstimateList
from books.model.Address import Address
from books.model.Email import Email
from books.model.ContactPerson import ContactPerson
from books.model.LineItem import LineItem
from books.model.PageContext import PageContext
from books.model.Tax import Tax
from books.model.CustomField import CustomField
from books.model.Email import Email
from books.model.EmailTemplate import EmailTemplate
from books.model.ToContact import ToContact
from books.model.FromEmail import FromEmail
from books.model.Template import Template
from books.model.Comment import Comment
from books.model.CommentList import CommentList
from books.model.TemplateList import TemplateList

class EstimatesParser:
    """This class is used to parse the json for estimates."""

    def get_list(self, response):
        """This method parses the given response and returns estimates list 
            object.
  
        Args:
            response(dict): Response containing json object for estimates.

        Returns:
            instance: Estimates list object.

        """
        resp = response['estimates']
        estimate_list = EstimateList()
        for value in resp:
            estimates = Estimate()
            estimates.set_estimate_id(value['estimate_id'])
            estimates.set_customer_name(value['customer_name'])
            estimates.set_customer_id(value['customer_id'])
            estimates.set_status(value['status'])
            estimates.set_estimate_number(value['estimate_number'])
            estimates.set_reference_number(value['reference_number'])
            estimates.set_date(value['date'])
            estimates.set_currency_id(value['currency_id'])
            estimates.set_currency_code(value['currency_code'])
            estimates.set_total(value['total'])
            estimates.set_created_time(value['created_time'])
            estimates.set_accepted_date(value['accepted_date'])
            estimates.set_declined_date(value['declined_date'])
            estimates.set_expiry_date(value['expiry_date'])
            estimate_list.set_estimates(estimates)
        page_context_object = PageContext()
        page_context = response['page_context']
        page_context_object.set_page(page_context['page'])
        page_context_object.set_per_page(page_context['per_page'])
        page_context_object.set_has_more_page(page_context['has_more_page'])
        page_context_object.set_report_name(page_context['report_name'])
        page_context_object.set_applied_filter(page_context['applied_filter'])
        page_context_object.set_sort_column(page_context['sort_column'])
        page_context_object.set_sort_order(page_context['sort_order'])
        estimate_list.set_page_context(page_context_object)
        return estimate_list


    def get_estimate(self, response):
        """This method parses the given response and returns Estimate object.

        Args:
            response(dict): Response containing json object for estimate.

        Returns:
            instance: Estimate object.

        """
        estimate = Estimate()
        resp = response['estimate']
        estimate.set_estimate_id(resp['estimate_id'])
        estimate.set_estimate_number(resp['estimate_number'])
        estimate.set_date(resp['date'])
        estimate.set_reference_number(resp['reference_number'])
        estimate.set_status(resp['status'])
        estimate.set_customer_id(resp['customer_id'])
        estimate.set_customer_name(resp['customer_name'])
        estimate.set_contact_persons(resp['contact_persons'])
        estimate.set_currency_id(resp['currency_id'])
        estimate.set_currency_code(resp['currency_code'])
        estimate.set_exchange_rate(resp['exchange_rate'])
        estimate.set_expiry_date(resp['expiry_date'])
        estimate.set_discount(resp['discount'])
        estimate.set_is_discount_before_tax(resp['is_discount_before_tax'])
        estimate.set_discount_type(resp['discount_type'])
        line_items = resp['line_items']
        for value in line_items:
            line_item = LineItem()
            line_item.set_item_id(value['item_id'])
            line_item.set_line_item_id(value['line_item_id'])
            line_item.set_name(value['name'])
            line_item.set_description(value['description'])
            line_item.set_item_order(value['item_order'])
            line_item.set_bcy_rate(value['bcy_rate'])
            line_item.set_rate(value['rate'])
            line_item.set_quantity(value['quantity'])
            line_item.set_unit(value['unit'])
            line_item.set_discount(value['discount'])
            line_item.set_tax_id(value['tax_id'])
            line_item.set_tax_name(value['tax_name'])
            line_item.set_tax_type(value['tax_type'])
            line_item.set_tax_percentage(value['tax_percentage'])
            line_item.set_item_total(value['item_total'])
            estimate.set_line_items(line_item)
        estimate.set_shipping_charge(resp['shipping_charge'])
        estimate.set_adjustment(resp['adjustment'])
        estimate.set_adjustment_description(resp['adjustment_description'])
        estimate.set_sub_total(resp['sub_total'])
        estimate.set_total(resp['total'])
        estimate.set_tax_total(resp['tax_total'])
        estimate.set_price_precision(resp['price_precision'])
        taxes = resp['taxes']
        for value in taxes:
            tax = Tax()
            tax.set_tax_name(value['tax_name'])
            tax.set_tax_amount(value['tax_amount'])
            estimate.set_taxes(tax)
        billing_address = resp['billing_address']
        billing_address_object = Address()
        billing_address_object.set_address(billing_address['address'])
        billing_address_object.set_city(billing_address['city'])
        billing_address_object.set_state(billing_address['state'])
        billing_address_object.set_zip(billing_address['zip']) 
        billing_address_object.set_country(billing_address['country'])   
        billing_address_object.set_fax(billing_address['zip'])
        estimate.set_billing_address(billing_address_object)

        shipping_address = resp['shipping_address']
        shipping_address_object = Address()
        shipping_address_object.set_address(shipping_address['address'])
        shipping_address_object.set_city(shipping_address['city'])
        shipping_address_object.set_state(shipping_address['state'])
        shipping_address_object.set_zip(shipping_address['zip']) 
        shipping_address_object.set_country(shipping_address['country'])   
        shipping_address_object.set_fax(shipping_address['zip'])
        estimate.set_shipping_address(shipping_address_object)

        estimate.set_notes(resp['notes'])
        estimate.set_terms(resp['terms'])
        custom_fields = resp['custom_fields']
        for value in custom_fields:
            custom_field = CustomField()
            custom_field.set_index(value['index'])
            custom_field.set_show_on_pdf(value['show_on_pdf'])
            custom_field.set_value(value['value'])
            custom_field.set_label(value['label'])
            estimate.set_custom_fields(custom_field)
        estimate.set_template_id(resp['template_id'])
        estimate.set_template_name(resp['template_name'])
        estimate.set_created_time(resp['created_time'])
        estimate.set_last_modified_time(resp['last_modified_time'])
        estimate.set_salesperson_id(resp['salesperson_id'])
        estimate.set_salesperson_name(resp['salesperson_name'])
        return estimate

    def get_message(self, response):
        """This method parses the given response and returns success message.

        Args:
            response(dict): Response containing json object.

        Returns:
            str: Success message.

        """
        return response['message']

    def get_email_content(self, response):
        """This method parses the given response and returns email object.

        Args:
            response(dict): Response containing json object for email content.

        Returns:
            instance: Email object.

        """
        email = Email()
        data = response['data']
        email.set_body(data['body'])
        email.set_error_list(data['error_list'])
        email.set_subject(data['subject'])
        for value in data['emailtemplates']:
            email_templates = EmailTemplate()
            email_templates.set_selected(value['selected'])
            email_templates.set_name(value['name'])
            email_templates.set_email_template_id(value['email_template_id'])
            email.set_email_templates(email_templates)
        to_contacts = data['to_contacts']
        for value in to_contacts:
            to_contact = ToContact()
            to_contact.set_first_name(value['first_name'])
            to_contact.set_selected(value['selected'])
            to_contact.set_phone(value['phone'])
            to_contact.set_email(value['email'])
            to_contact.set_contact_person_id(value['contact_person_id'])
            to_contact.set_last_name(value['last_name'])
            to_contact.set_salutation(value['salutation'])
            to_contact.set_mobile(value['mobile'])
            email.set_to_contacts(to_contact)
        email.set_file_name(data['file_name'])
        from_emails = data['from_emails']
        for value in from_emails:
            from_email = FromEmail()
            from_email.set_user_name(value['user_name'])
            from_email.set_selected(value['selected'])
            from_email.set_email(value['email'])
            email.set_from_emails(from_email)
        email.set_customer_id(data['customer_id'])
        return email

    def get_billing_address(self, response):
        """This method parses the given response and returns billing address object.

        Args:
            response(dict): Response containing json object for billing address.

        Returns:
            instacne: Billing address object.

        """
        address = response['billing_address']
        address_object = Address()
        address_object.set_address(address['address'])
        address_object.set_city(address['city'])
        address_object.set_state(address['state'])
        address_object.set_zip(address['zip'])
        address_object.set_country(address['country'])
        address_object.set_fax(address['fax'])
        address_object.set_is_update_customer(address['is_update_customer'])
        return address_object

    def get_shipping_address(self, response):
        """This method parses the given response and returns shipping address 
            object.

        Args:
            response(dict): Response containing json object for shipping 
                address.
 
        Returns:
            instance: Shipping address object.

        """
        address = response['shipping_address']
        address_object = Address()
        address_object.set_address(address['address'])
        address_object.set_city(address['city'])
        address_object.set_state(address['state'])
        address_object.set_zip(address['zip'])
        address_object.set_country(address['country'])
        address_object.set_fax(address['fax'])
        address_object.set_is_update_customer(address['is_update_customer'])
        return address_object

    def estimate_template_list(self, response):
        """This method parses the given response and returns estimate template 
            list object.

        Args:
            response(dict): Response containing json object for estimate 
                template list.


        Returns:
            instance: Template list object.

        """
        template_list = TemplateList()
        resp = response['templates']
        for value in resp:
            template = Template()
            template.set_template_name(value['template_name'])
            template.set_template_id(value['template_id'])
            template.set_template_type(value['template_type'])
            template_list.set_templates(template)
        return template_list
      
    def get_comments(self, response):
        """This method parses the given response and returns comments list 
            object.
 
        Args:
            response(dict): Response containing json object for comments list.

        Returns:
            instance: Comments list object.

        """        
        comments = response['comments']
        comments_list = CommentList()
        for value in comments:
            comment = Comment()
            comment.set_comment_id(value['comment_id'])
            comment.set_estimate_id(value['estimate_id'])
            comment.set_description(value['description'])
            comment.set_commented_by_id(value['commented_by_id'])
            comment.set_commented_by(value['commented_by'])
            comment.set_comment_type(value['comment_type'])
            comment.set_date(value['date'])
            comment.set_date_description(value['date_description'])
            comment.set_time(value['time'])
            comment.set_operation_type(value['operation_type'])
            comment.set_transaction_id(value['transaction_id'])
            comment.set_transaction_type(value['transaction_type'])
            comments_list.set_comments(comment)
        return comments_list

    def get_comment(self, response):
        """This method parses the given response and returns comments object.

        Args:
            response(dict): Response containing json object for comments 
                object.

        Returns:
            instance: Comments object.

        """
        comment = response['comment']
        comment_object = Comment()
        comment_object.set_comment_id(comment['comment_id'])
        comment_object.set_estimate_id(comment['estimate_id'])
        comment_object.set_description(comment['description'])
        comment_object.set_commented_by_id(comment['commented_by_id'])
        comment_object.set_commented_by(comment['commented_by'])
        comment_object.set_date(comment['date'])
        comment_object.set_date_description(comment['date_description'])
        comment_object.set_time(comment['time'])
        comment_object.set_comment_type(comment['comment_type'])
        return comment_object





#$Id$

class SearchCriteria:
    """This class is used to create object for Criteria."""
    def __init__(self): 
        """Initialize parameter for search criteria."""
        self.column_name = ''
        self.search_text = ''
        self.comparator = ''

    def set_column_name(self, column_name):
        """Set column name.

        Args:
            column_name(str): Column name.

        """
        self.column_name = column_name

    def get_column_name(self):
        """Get column name.

        Returns:
            str: Column name.

        """
        return self.column_name

    def set_search_text(self, search_text):
        """Set search text.

        Args:
            search_text(str): Search text.

        """
        self.search_text = search_text

    def get_search_text(self):
        """Get search text.

        Returns:
            str: Search text.

        """
        return self.search_text

    def set_comparator(self, comparator):
        """Set comparator.
 
        Args:
            comparator(str): Comparator.
 
        """
        self.comparator = comparator

    def get_comparator(self):
        """Get compparator.

        Returns:
            str: Comparator.

        """
        return self.comparator




#$Id$#

from books.model.CustomerPayment import CustomerPayment
from books.model.CustomerPaymentList import CustomerPaymentList
from books.model.CreditNoteRefund import CreditNoteRefund
from books.model.CreditNoteRefundList import CreditNoteRefundList
from books.model.PageContext import PageContext
from books.model.Invoice import Invoice

class CustomerPaymentsParser:
    """This class is used to parse the json for customer payments."""
 
    def customer_payments(self,response):
        """This method parses the given response and returns customer payments 
            list object.

        Args:
            response(dict): Response containing json object for customer 
                payments list.
      
        Returns:
            instance: Customer payments list object.
        
        """
        customer_payment_list=CustomerPaymentList()
        for value in response['customerpayments']:
            customer_payment=CustomerPayment()
            customer_payment.set_payment_id(value['payment_id'])
            customer_payment.set_payment_number(value['payment_number'])
            customer_payment.set_invoice_numbers(value['invoice_numbers'])
            customer_payment.set_date(value['date'])
            customer_payment.set_payment_mode(value['payment_mode'])
            customer_payment.set_amount(value['amount'])
            customer_payment.set_bcy_amount(value['bcy_amount'])
            customer_payment.set_unused_amount(value['unused_amount'])
            customer_payment.set_bcy_unused_amount(value['bcy_unused_amount'])
            customer_payment.set_account_id(value['account_id'])
            customer_payment.set_account_name(value['account_name'])
            customer_payment.set_description(value['description'])
            customer_payment.set_reference_number(value['reference_number'])
            customer_payment.set_customer_id(value['customer_id'])
            customer_payment.set_customer_name(value['customer_name'])
            customer_payment.set_created_time(value['created_time'])
            customer_payment.set_last_modified_time(\
            value['last_modified_time'])
            customer_payment_list.set_customer_payments(customer_payment)
        page_context=response['page_context']
        page_context_obj=PageContext()
        page_context_obj.set_page(page_context['page'])
        page_context_obj.set_per_page(page_context['per_page'])
        page_context_obj.set_has_more_page(page_context['has_more_page'])
        page_context_obj.set_report_name(page_context['report_name'])
        page_context_obj.set_applied_filter(page_context['applied_filter'])
        page_context_obj.set_sort_column(page_context['sort_column'])
        page_context_obj.set_sort_order(page_context['sort_order'])
        customer_payment_list.set_page_context(page_context_obj)
        return customer_payment_list

    def payment_refunds(self,response):
        """This method parses the given response and returns credit notes
            refund list.

        Args:
            response(dict): Repsonse containing json object for credit notes
                list.

        Returns:
            instance: Creditnote list object.

        """
        payment_refunds_list=CreditNoteRefundList()
        if 'payment_refunds' not in response:
            response['payment_refunds'] = [response['payment_refund']]
        for value in response['payment_refunds']:
            payment_refund=CreditNoteRefund()
            payment_refund.set_creditnote_refund_id(value['payment_refund_id'])
            payment_refund.set_creditnote_id(value['payment_id'])
            payment_refund.set_date(value['date'])
            payment_refund.set_refund_mode(value['refund_mode'])
            payment_refund.set_reference_number(value['reference_number'])
            payment_refund.set_description(value['description'])
            payment_refund.set_amount(value['amount'])
            payment_refunds_list.set_creditnote_refunds(payment_refund)
        if 'page_context' in response:
            page_context=response['page_context']
            page_context_obj=PageContext()
            page_context_obj.set_page(page_context['page'])
            page_context_obj.set_per_page(page_context['per_page'])
            page_context_obj.set_has_more_page(page_context['has_more_page'])
            page_context_obj.set_report_name(page_context['report_name'])
            page_context_obj.set_sort_column(page_context['sort_column'])
            page_context_obj.set_sort_order(page_context['sort_order'])
            payment_refunds_list.set_page_context(page_context_obj)
        return payment_refunds_list


    def get_customer_payment(self,response):
        """This method parses the given response and returns customer payments 
            object.

        Args: 
            response(dict): Response containing json object for customer 
                payments.
      
        Returns:
            instance: Customer payments object.
        
        """
        payment=response['payment']
        customer_payment=CustomerPayment()
        customer_payment.set_payment_id(payment['payment_id'])
        customer_payment.set_customer_id(payment['customer_id'])
        customer_payment.set_customer_name(payment['customer_name'])
        customer_payment.set_payment_mode(payment['payment_mode'])
        customer_payment.set_date(payment['date'])
        customer_payment.set_account_id(payment['account_id'])
        customer_payment.set_account_name(payment['account_name'])
        customer_payment.set_exchange_rate(payment['exchange_rate'])
        customer_payment.set_amount(payment['amount'])
        customer_payment.set_bank_charges(payment['bank_charges'])
        customer_payment.set_tax_account_id(payment['tax_account_id'])
        customer_payment.set_tax_account_name(payment['tax_account_name'])
        customer_payment.set_tax_amount_withheld(\
        payment['tax_amount_withheld'])
        customer_payment.set_description(payment['description'])
        customer_payment.set_reference_number(payment['reference_number'])
        invoices=[]
        for value in payment['invoices']:
            invoice=Invoice()
            invoice.set_invoice_number(value['invoice_number'])
            invoice.set_invoice_payment_id(value['invoice_payment_id'])
            invoice.set_invoice_id(value['invoice_id'])
            invoice.set_amount_applied(value['amount_applied'])
            invoice.set_tax_amount_withheld(value['tax_amount_withheld'])
            invoice.set_total(value['total'])
            invoice.set_balance(value['balance'])
            invoice.set_date(value['date'])
            invoice.set_due_date(value['due_date'])
            invoices.append(invoice)
        customer_payment.set_invoices(invoices) 
        return customer_payment 

    def get_message(self,response): 
        """This method parses the given response and returns the message.
        
        Args:
            response(dict): Response containing json object.
 
        Returns:
            str: Success message.

        """
        return response['message']




#$Id$

from books.model.Organization import Organization
from books.model.Customer import Customer

class PlaceholderAddressFormat:
    """This class is used to create object for Palceholders Address Format."""
    def __init__(self):
        """Initialize parameters for placeholders address format."""
        self.organization = Organization()
        self.customer = Customer()

    def set_organization(self, organization):
        """Set organization.

        Args:
            organization(instance): Organization object.

        """
        self.organization = Organization()
 
    def get_organization(self):
        """Get organization.

        Returns:
            instance: Organization object.

        """ 
        return self.organization

    def set_customer(self, customer):
        """Set customer.

        Args:
            customer(instance):Customer object.

        """
        self.customer = customer

    def get_customer(self):
        """Get customer.

        Returns:
            instance: Customer object.

        """
        return self.customer




#$Id$

class Tax:
    """This class is used to create an object for tax."""
    def __init__(self):
        """Initialize parameters for tax."""
        self.tax_name = ''
        self.tax_amount = 0.0
        self.tax_id = ''
        self.tax_percentage = 0.0
        self.tax_type = ''
        self.tax_specification = ''

    def set_tax_id(self, tax_id):
        """Set tax id.

        Args:
            tax_id(str): Tax id.

        """ 
        self.tax_id = tax_id

    def get_tax_id(self):
        """Get tax id.

        Returns:
            str: Tax id.

        """
        return self.tax_id

    def set_tax_percentage(self, tax_percentage):
        """Set tax percentage.

        Args:
            tax_percentage(float): Tax percentage.

        """
        self.tax_percentage = tax_percentage

    def get_tax_percentage(self):
        """Get tax percentage.

        Args:
            float: Tax percentage.

        """
        return self.tax_percentage
   
    def set_tax_type(self, tax_type):
        """Set tax type.

        Args:
            tax_type(str): Tax type.

        """
        self.tax_type = tax_type

    def get_tax_type(self):
        """Get tax type.

        Returns:
            str: Tax type.
 
        """
        return self.tax_type
  
    def set_tax_name(self, tax_name):
        """Set tax name.

        Args:
            tax_name(str): Tax name.
 
        """
        self.tax_name = tax_name

    def get_tax_name(self):
        """Get tax name.

        Returns:
            str: Tax name.

        """
        return self.tax_name

    def set_tax_amount(self, tax_amount):
        """Set tax amount.
 
        Args:
            tax_amount(float): Tax amount.

        """
        self.tax_amount = tax_amount

    def get_tax_amount(self):
        """Get tax amount.

        Returns:
            float: Tax amount.

        """
        return self.tax_amount

    def set_tax_specification(self, tax_specification):
        """Set tax Specification.

        Args:
            tax_specification(str): Tax Specification.

        """
        self.tax_specification = tax_specification

    def get_tax_specification(self):
        """Get tax Specification.

        Returns:
            str: Tax Specification.

        """
        return self.tax_specification

    def to_json(self):
        """This method is used to convert tax object to json format.

        Returns:
            dict: Dictionary containing json object for tax.

        """
        data = {}
        if self.tax_name != '':
            data['tax_name'] = self.tax_name
        if self.tax_percentage > 0:
            data['tax_percentage'] = self.tax_percentage
        if self.tax_type != '':
            data['tax_type'] = self.tax_type
        return data





#$Id$

class CustomField:
    """This class is used to create custom field."""
    def __init__(self):
        """Initialize the parameters for custom field object"""
        self.index = 0
        self.show_on_pdf = None
        self.value = ''
        self.label = ''
  
    def set_index(self, index):
        """Set index for custom field.
        
        Args:
            index(int): Index for custom field.
 
        """
        self.index = index

    def get_index(self):
        """Get index for custom field.
        
        Returns:
            int: Index for custom field.
  
        """
        return self.index
 
    def set_show_on_pdf(self, show_on_pdf):
        """Set whether to show as pdf or not.
 
        Args:
            show_on_pdf(bool): True to show as pdf else False.

        """
        self.show_on_pdf = show_on_pdf
    def get_show_on_pdf(self):
        """Get whether to show as pdf or not.
    
        Returns:
            bool: True to show as pdf else False.

        """
        return self.show_on_pdf

    def set_value(self, value):
        """Set value for custom field.
 
        Args:
            value(str): Value for custom field.

        """
        self.value = value

    def get_value(self):
        """Get value of custom field.
     
        Returns:
            str: Value for custom field.

        """
        return self.value
 
    def set_label(self, label):
        """Set label for custom field.
          
        Args:
            label(str): Label for custom field.

        """
        self.label = label

    def get_label(self):
        """Get label of custom field.
      
        Returns:
            str: Label of custom field.
 
        """
        return self.label

    def set_invoice(self, invoice):
        """Set invoice.

        Args:
            invoice(instance): Invoice custom field.

        """
        self.invoice.append(invoice)

    def get_invoice(self):
        """Get invoice.

        Returns: 
            list of instance: List of Invoice custom field.

        """
        return self.invoice
  
    def set_contact(self, contact):
        """Set cocntact.

        Args: 
            contact(instance): Contact custom field.

        """
        self.contact.append(contact)

    def get_contact(self):
        """Get contact.

        Returns: 
            list of instance: List of Contact custom field.

        """
        return self.custom_field

    def set_estimate(self, estimate): 
        """Set estimate.

        Args:
            estimate(instance): Estimate custom field.

        """
        self.estimate.append(estimate)

    def get_estimate(self):
        """Get estimate.

        Returns:
            list of instance: List of estimate custom field.

        """
        return self.estimate

    def to_json(self):
        """This method is used to convert custom field object to json object.

        Returns:
            dict: Dictionary containing json object for custom field.

        """
        data = {}
        #if self.index != None:
            #data['index'] = self.index
        if self.value != '':
            data['value'] = self.value
            data['api_name'] = self.label
        return data




#$Id$

from books.model.PageContext import PageContext

class RecurringInvoiceList:
    """This class is used to create object for Recurring invoice list."""
    def __init__(self):
        """Initialize parameters for Recurring invoice list."""  
        self.recurring_invoices = []
        self.page_context = PageContext()
   
    def set_recurring_invoices(self, recurring_invoices):
        """Set recurring invoice.

        Args:
            recurring_invoices(instance): Recurring invoice object.

        """
        self.recurring_invoices.extend(recurring_invoices)
 
    def get_recurring_invoices(self):
        """Get recurring invoice.

        Returns:
            list: List of recurring invoice objects.

        """
        return self.recurring_invoices

    def set_page_context(self, page_context):
        """Set page context.

        Args: 
            page_context(instance): Page context instance.

        """
        self.page_context = page_context

    def get_page_context(self): 
        """Get page context.

        Returns:
            instance: Page context instance.
     
        """
        return self.page_context




#$Id$

from books.model.Address import Address

class Organization: 
    """This class is used to create object for organization."""
    def __init__(self):
        """Initialize parameters for organization object. """
        self.organization_id = ''
        self.name = ''
        self.is_default_org = None
        self.account_created_date = ''
        self.time_zone = ''
        self.language_code = ''
        self.date_format = ''
        self.field_separator = ''
        self.fiscal_year_start_month = ''
        self.contact_name = ''
        self.industry_type = ''
        self.industry_size = ''
        self.company_id_label = ''
        self.company_id_value = ''
        self.tax_id_label = ''
        self.tax_id_value = ''
        self.currency_id = ''
        self.currency_code = ''
        self.currency_symbol = ''
        self.currency_format = ''
        self.price_precision = 0
        self.address = Address()
        self.org_address = ''
        self.remit_to_address = ''
        self.phone = ''
        self.fax = ''
        self.website = ''
        self.email = ''
        self.tax_basis = ''
        self.is_org_active = None
        self.name = ''
        self.value = ''
        self.version = ''
        self.plan_type = 0
        self.plane_name = ''
        self.plan_period = ''
        self.tax_group_enabled = None
        self.account_created_date_formatted = ""
        self.zi_migration_status = 0
        self.user_role = ''
        self.custom_fields = []
        self.is_new_customer_custom_fields = None
        self.is_portal_enabled = None
        self.portal_name = ''
        self.tax_type = ''

    def set_organization_id(self, organization_id):
        """Set organization id.

        Args: 
            organization_id(str): Organization id.

        """
        self.organization_id = organization_id

    def get_organization_id(self):
        """Get organization id.

        Returns:
            str: Organization id.

        """
        return self.organization_id

    def set_name(self, name):
        """Set name.

        Args:
            name(str): Name.

        """
        self.name = name

    def set_is_default_org(self, is_default_org):
        """Set whether it is default organization.

        Args:
            is_default_org(bool): True if it is default organization else false.

        """
        self.is_default_org = is_default_org

    def get_is_default_org(self): 
        """Get whether it is default organization.

        Returns:
            bool: True if it is default organization else false.

        """
        return self.is_default_org

    def set_account_created_date(self, account_created_date):
        """Set account created date.

        Args:
            account_created_date(str): Account created date.

        """
        self.account_created_date = account_created_date

    def get_account_created_date(self):
        """Get account created date.

        Returns:
            str: Account created date.

        """
        return self.account_created_date

    def set_time_zone(self, time_zone):
        """Set time zone.

        Args:
            time_zone(str): Time zone.

        """
        self.time_zone = time_zone

    def get_time_zone(self):
        """Get time zone.

        Returns:
            str: Time zone.

        """
        return self.time_zone

    def set_language_code(self, language_code):
        """Set language code.

        Args:
            language_code(str): Language code.

        """
        self.language_code = language_code

    def get_language_code(self):
        """Get language code.

        Returns:
            str: Language code.

        """
        return self.language_code

    def set_date_format(self, date_format):
        """Set date format.

        Args:
            date_format(str): Date format.

        """
        self.date_format = date_format

    def get_date_format(self):
        """Get date format.

        Returns:
            str: Date format.

        """
        return self.date_format

    def set_field_separator(self, field_separator):
        """Set field separator.

        Args:
            field_separator(str): Field separator.

        """
        self.field_separator = field_separator

    def get_field_separator(self):
        """Get field separator.

        Returns:
            str: Field separator.

        """
        return self.field_separator

    def set_fiscal_year_start_month(self, fiscal_year_start_month):
        """Set fiscal year field separator.

        Args:
            fiscal_year_start_month(str): Fiscal year start month.

        """
        self.fiscal_year_start_month = fiscal_year_start_month

    def get_fiscal_year_start_month(self):
        """Get fiscal year start month.

        Returns:
            str: Fiscal year start month.

        """
        return self.fiscal_year_start_month

    def set_contact_name(self, contact_name): 
        """Set contact name.

        Args: 
            contact_name(str): Contact name.

        """
        self.contact_name = contact_name

    def get_contact_name(self):
        """Get contact name.

        Returns:
            str: Contact name.

        """
        return self.contact_name

    def set_industry_type(self, industry_type):
        """Set industry type.

        Args:
            industry_type(str): Industry type.

        """
        self.industry_type = industry_type

    def get_industry_type(self):
        """Get industry type.

        Returns:
            str: Industry type.

        """ 
        return self.industry_type

    def set_industry_size(self, industry_size):
        """Set industry size.

        Args:
            industry_size(str): Industry size.

        """
        self.industry_size = industry_size

    def get_industry_size(self):
        """Get industry size.

        Returns:
            str: Industry size.

        """
        return self.industry_size

    def set_company_id_label(self, company_id_label):
        """Set company id label.

        Args:
            company_id_label(str): Company id label.

        """
        self.company_id_label = company_id_label

    def get_company_id_label(self):
        """Get company id label.

        Returns:
            str: Company id label.

        """
        return self.company_id_label

    def set_company_id_value(self, company_id_value):
        """Set company id value.

        Args:
            company_id_value(str): Company id value.

        """
        self.company_id_value = company_id_value

    def get_company_id_value(self):
        """Get company id value.

        Returns:
            str: Company id value.

        """
        return self.company_id_value

    def set_tax_id_label(self, tax_id_label):
        """Set tax id label.

        Args:
            tax_id_label(str): Tax id label.

        """
        self.tax_id_label = tax_id_label

    def get_tax_id_label(self):
        """Get tax id label.

        Retruns:
            str: Tax id label.

        """
        return self.tax_id_label

    def set_tax_id_value(self, tax_id_value):
        """Set tax id value.

        Args:
            tax_id_value(str): Tax id value.

        """
        self.tax_id_value = tax_id_value

    def get_tax_id_value(self):
        """Get atx id value.

        Returns:
            str: Tax id value.

        """
        return self.tax_id_value

    def set_currency_id(self, currency_id):
        """Set currency id.

        Args:
            currency_id(str): Currency id.

        """
        self.currency_id = currency_id

    def get_currency_id(self):
        """Get currency id.

        Returns:
            str: Currency id.

        """
        return self.currency_id

    def set_currency_code(self, currency_code):
        """Set currency code.

        Args:
            currency_code(str): Currency code.

        """
        self.currency_code = currency_code

    def get_currency_code(self):
        """Get currency code.

        Returns:
            str: Currency code.

        """
        return self.currency_code

    def set_currency_symbol(self, currency_symbol):
        """Set currency symbol.

        Args:
            currency_symbol(str): Currency symbol.

        """ 
        self.currency_symbol = currency_symbol

    def get_currency_symbol(self):
        """Get currency symbol.

        Returns:
            str: Currency symbol.

        """
        return self.currency_symbol

    def set_currency_format(self, currency_format):
        """Set currency format.

        Args:
            currency_format(str): Currency format.

        """
        self.currency_format = currency_format

    def get_currency_format(self):
        """Get currency format.

        Retruns:
            str: Currency format.

        """
        return self.currency_format

    def set_price_precision(self, price_precision):
        """Set price precision.

        Args:
            price_precision(int): Price precision.

        """
        self.price_precision = price_precision

    def set_address(self, address):
        """Set address.

        Args:
            address(instance): Address

        """
        self.address = address

    def get_address(self):
        """Get address.

        Returns:
            instance: Address.

        """
        return self.address

    def set_org_address(self, org_address):
        """Set organization address.

        Args:
            org_address(str): Organization address.

        """
        self.org_address = org_address

    def get_org_address(self):
        """Get organization address.

        Returns:
            str: Organization address.

        """
        return self.org_address

    def set_remit_to_address(self, remit_to_address):
        """Set remit to address.

        Args:
            remit_to_address(str): Remit to address.
 
        """
        self.remit_to_address = remit_to_address

    def get_remit_to_address(self):
        """Get remit to address.

        Returns:
            str: Remit to address.

        """ 
        return self.remit_to_address

    def set_phone(self, phone):
        """Set phone.

        Args:
            phone(str): Phone.

        """
        self.phone = phone

    def get_phone(self):
        """Get phone.

        Returns:
            str: Phone.

        """
        return self.phone

    def set_fax(self, fax):
        """Set fax.

        Args:
            fax(str): Fax.

        """
        self.fax = fax

    def get_fax(self):
        """Get fax.

        Returns:
            str: Fax.

        """
        return self.fax

    def set_website(self, website):
        """Set website.

        Args:
            website(str): Website.

        """
        self.website = website

    def set_email(self, email):
        """Set email.

        Args:
            email(str): Email.

        """
        self.email = email

    def get_email(self):
        """Get email.

        Returns:
            str: Email.

        """
        return self.email

    def set_tax_basis(self, tax_basis):
        """Set tax basis.

        Args:
            tax_basis(str): Tax basis.
      
        """
        self.tax_basis = tax_basis

    def get_tax_basis(self):
        """Get tax basis.

        Returns:
            str: Tax basis.

        """
        return self.tax_basis

    def set_is_org_active(self, is_org_active):
        """Set whether it the organization is active or not.

        Args:
            is_org_active(bool): True if organization is active else false.

        """
        self.is_org_active = is_org_active

    def set_name(self, name):
        """Set name.

        Args:
            name(str): Name.

        """
        self.name = name

    def get_name(self):
        """Get name.

        Returns:
            str: Name.

        """
        return self.name

    def set_value(self, value):
        """Set value.

        Args:
            value(str): Value.

        """
        self.value = value

    def get_value(self):
        """Get value.

        Returns:
            str: Value.

        """
        return self.value

    def set_version(self, version):
        """Set version.
 
        Args:
            version(str): Version

        """
        self.version = version

    def get_version(self):
        """Get version.

        Returns:
            str: Version.

        """
        return self.version

    def set_plan_type(self, plan_type):
        """Set plan type.

        Args:
            plan_type(int): Plan type.

        """
        self.plan_type = plan_type

    def get_plan_type(self):
        """Get plan type.

        Returns: 
            int: Plan type.

        """
        return self.plan_type

    def set_plan_name(self, plan_name):
        """Set plan name.

        Args:
            plan_name(str): Plan name.

        """
        self.plan_name = plan_name

    def get_plan_name(self):
        """Get plan name.

        Args:
            str: Plan name.

        """
        return self.plan_name

    def set_plan_period(self, plan_period):
        """Set plan period.

        Args:
            plan_period(str): Plan period.

        """
        self.plan_period = plan_period

    def get_plan_period(self):
        """Get plan period.

        Returns:
            str: Plan period.

        """
        return self.plan_period

    def set_tax_group_enabled(self, tax_group_enabled):
        """Set tax group enabled.

        Args:
            tax_group_enabled(bool): Tax group enabled.

        """
        self.tax_group_enabled = tax_group_enabled

    def get_tax_group_enabled(self):
        """Get tax group enabled.

        Returns:
            bool: Tax group enabled.

        """
        return self.tax_group_enabled

    def set_account_created_date_formatted(self, account_created_date_formatted):
        """Set account created date formatted.

        Args:
            account_created_date_formatted(str): Account created date formatted.

        """
        self.account_created_date_formatted = account_created_date_formatted

    def get_account_created_date_formatted(self):
        """Get account created date formatted.

        Returns: 
            str: Account created date formatted.

        """
        return self.account_created_date_formatted

    def set_zi_migration_status(self, zi_migration_status):
        """Set zi migration status.

        Args:
            zi_migration_status(int): Zi migration status.

        """
        self.zi_migration_status = zi_migration_status

    def get_zi_migration_status(self):
        """Get zi migration status .

        Returns:
            int: Zi migration status.

        """
        return self.zi_migration_status

    def set_custom_fields(self, custom_field):
        """Set custom fields.

        Args:
            custom_field(instance): Custom field.

        """
        self.custom_fields.append(custom_field)

    def get_custom_fields(self):
        """Get custom fields.

        Returns:
            list of instance: List of custom fields object.

        """
        return self.custom_fields

    def set_user_role(self, user_role):
        """Set user role.

        Args:
            user_role(str): User role.

        """
        self.user_role = user_role

    def get_user_role(self):
        """Get user role.

        Returns:
            str: User role.

        """
        return self.user_role

    def set_is_new_customer_custom_fields(self, is_new_customer_custom_fields):
        """Set whether new customer custom fields or not.

        Args:
            is_new_customer_custom_fields(bool): True if new customer custom fields else False.

        """
        self.is_new_customer_custom_fields = is_new_customer_custom_fields

    def get_is_new_customer_custom_fields(self):
        """Get whether new customer custom fields or not.

        Returns:
            bool: True if new customer custom fields else false.

        """ 
        return self.is_new_customer_custom_fields

    def set_is_portal_enabled(self, is_portal_enabled):
        """Set whether portal is enabled or not.

        Args:
            is_portal_enabled(bool): True if portal enabled else false.

        """
        self.is_portal_enabled = is_portal_enabled

    def get_is_portal_enabled(self):
        """Get whether is portal enabled.

        Returns:
            bool: True if portal is enabled else false.

        """
        return self.is_portal_enabled

    def set_portal_name(self, portal_name):
        """Set portal name.

        Args:
            portal_name(str): Portal name.

        """
        self.portal_name = portal_name

    def get_portal_name(self):
        """Get portal name.

        Returns:
            str: Portal name.

        """
        return self.portal_name

    def set_tax_type(self, tax_type):
        """Set tax type.

        Args:
            tax_type(str): Tax type.

        """
        self.tax_type = tax_type

    def get_tax_type(self):
        """Get tax type.

        Returns:
            str: Tax type.

        """
        return self.tax_type

    def to_json(self):
        """This method is used to convert organizations object to json format.

        Returns:
            dict: Dictionary containing json object for organizations.

        """
        data = {}
        if self.name != '':
            data['name'] = self.name
        if self.address is not None:
            data['address'] = self.address.to_json()
        if self.industry_type != '':
            data['industry_type'] = self.industry_type
        if self.industry_size != '':
            data['industry_size'] = self.industry_size
        if self.fiscal_year_start_month != '':
            data['fiscal_year_start_month'] = self.fiscal_year_start_month
        if self.currency_code != '':
            data['currency_code'] = self.currency_code
        if self.time_zone != '':
            data['time_zone'] = self.time_zone
        if self.date_format != '':
            data['date_format'] = self.date_format
        if self.field_separator != '':
            data['field_separator'] = self.field_separator
        if self.language_code != '':
            data['language_code'] = self.language_code
        if self.tax_basis != '':
            data['tax_basis'] = self.tax_basis
        if self.org_address != '':
            data['org_address'] = self.org_address
        if self.remit_to_address != '':
            data['remit_to_address'] = self.remit_to_address
        if self.tax_type != '':
            data['tax_type'] = self.tax_type
        return data



#$Id$

from books.model.Address import Address

class Bill:
    """This class is used to create an object for Bills."""
    def __init__(self):
        """Initialize the parameters for bills object."""
        self.bill_id = ''
        self.bill_payment_id = ''
        self.vendor_id = ''
        self.vendor_name = ''
        self.unused_credits_payable_amount = 0.0
        self.status = ''
        self.bill_number = ''
        self.date = ''
        self.due_date = ''
        self.due_days = ''
        self.reference_number = ''
        self.due_by_days = 0
        self.due_in_days = ''
        self.currency_id = ''
        self.currency_code = ''
        self.currency_symbol = ''
        self.price_precision = 0
        self.exchange_rate = 0.0
        self.line_items = []
        self.sub_total = 0.0
        self.tax_total = 0.0
        self.total = 0.0
        self.taxes = []
        self.amount_applied = 0.0
        self.payment_made = 0.0
        self.balance = 0.0
        self.billing_address = Address()
        self.payments = []
        self.created_time = ''
        self.last_modified_time = ''
        self.reference_id = ''
        self.attachment_name = ''
        self.account_id = ''
        self.description = ''
        self.rate = 0.0
        self.quantity = 0.0
        self.tax_id = ''
        self.notes = ''
        self.terms = ''
        self.is_inclusive_tax = False
   
    def set_bill_id(self, bill_id):
        """Set bill id.

        Args: 
            bill_id(str): Bill id.
 
        """
        self.bill_id = bill_id

    def get_bill_id(self):
        """Get bill id.

        Returns:
            str: Bill id.

        """
        return self.bill_id
  
    def set_bill_payment_id(self, bill_payment_id):
        """Set bill payment id.

        Args:
            bill_payment_id(str): Bill payment id.

        """
        self.bill_payment_id = bill_payment_id
 
    def get_bill_payment_id(self):
        """Get bill payment id.

        Returns:
            str: Bill payment id.

        """
        return self.bill_payment_id
 
    def set_amount_applied(self, amount_applied):
        """Set amount applied.

        Args:
            amount_applied(float): Amount applied.
 
        """
        self.amount_applied = amount_applied

    def get_amount_applied(self):
        """Get amount applied.

        Returns:
            float: Amount applied.

        """
        return self.amount_applied

    def set_vendor_id(self, vendor_id):
        """Set vendor id.

        Args:
            vendor_id(str): Vendor id.

        """
        self.vendor_id = vendor_id

    def set_is_inclusive_tax(self, is_inclusive_tax):
        """Set vendor id.

        Args:
            is_inclusive_tax(bool): is_inclusive_tax.

        """
        self.is_inclusive_tax = is_inclusive_tax

    def get_vendor_id(self):
        """Get vendor id.

        Returns:
            str: Vendor id.

        """
        return self.vendor_id

    def set_vendor_name(self, vendor_name):
        """Set vendor name.

        Args:
            vendor_name(str): Vendor name.

        """
        self.vendor_name = vendor_name

    def get_vendor_name(self):
        """Get vendor name.

        Returns:
            str: Vendor name.

        """
        return self.vendor_name

    def set_unused_credits_payable_amount(self, unused_credits_payable_amount):
        """Set unused amount payable amount.

        Args:
            unused_credits_payable_amount(float): Unused amount payable amount.

        """
        self.unused_credits_payable_amount = unused_credits_payable_amount

    def get_unused_payable_amount(self):
        """Get unused amount payable amount.

        Returns:
            float: Unused amount payable amount.
 
        """
        return self.unused_credits_payable_amount
 
    def set_status(self, status):
        """Set status.

        Args: 
            status(str): Status.

        """
        self.status = status

    def get_status(self):
        """Get status.

        Returns:
            str: Status.

        """
        return self.status

    def set_bill_number(self, bill_number):
        """Set bill number.

        Args: 
            bill_number(str): Bill number.

        """
        self.bill_number = bill_number

    def get_bill_number(self):
        """Get bill number.

        Returns:
            str: Bill number.

        """
        return self.bill_number

    def set_reference_number(self, reference_number):
        """Set reference number.

        Args:
            reference_number(str): Reference number.

        """
        self.reference_number = reference_number

    def get_reference_number(self):
        """Get reference number.

        Returns:
            str: Reference number.

        """
        return self.reference_number
  
    def set_date(self, date): 
        """Set date.

        Args: 
            date(str): Date.

        """
        self.date = date

    def get_date(self):
        """Get date.

        Returns:
            str: Date.

        """
        return self.date

    def set_due_date(self, due_date):
        """Set due date.

        Args: 
            due_date(str): Due date.

        """
        self.due_date = due_date

    def get_due_date(self):
        """Get due date.

        Returns:
            str: Due date.

        """
        return self.due_date
  
    def set_due_by_days(self, due_by_days):
        """Set due by days.
 
        Args:
            due_by_days(int): Due by days.

        """
        self.due_by_days = due_by_days

    def get_due_by_days(self): 
        """Get due by days.

        Returns: 
            int: Due by days.

        """
        return self.due_by_days
  
    def set_due_in_days(self, due_in_days):
        """Set due in days.

        Args:
            due_in_days(str): Due in days.

        """
        self.due_in_days = self.due_in_days

    def get_due_in_days(self): 
        """Get due in days.

        Returns:
            str: Due in days.

        """
        return self.due_in_days
  
    def set_currency_id(self, currency_id):
        """Set currency_id.

        Args:
            currency_id(str): Currency id.

        """
        self.currency_id = currency_id

    def get_currency_id(self):
        """Get currency id.

        Returns:
            str: Currency id.

        """
        return currency_id

    def set_currency_code(self, currency_code):
        """Set currency code.

        Args:
            currency_code(str): Currency code.

        """
        self.currency_code = currency_code

    def get_currency_code(self):
        """Get currency code.

        Returns:
            str: Currency code.

        """
        return self.currency_code

    def set_currency_symbol(self, currency_symbol):
        """Set currency symbol.

        Args:
            currency_symbol(str): Currency symbol.

        """
        self.currency_symbol = currency_symbol

    def get_currency_symbol(self):
        """Get currency symbol.

        Returns:
            str: Currency symbol.

        """
        return self.currency_symbol
  
    def set_price_precision(self, price_precision):
        """Set price precision.

        Args: 
            price_precision(int): Price precision.

        """
        self.price_precision = price_precision

    def get_price_precision(self):
        """Get price precision.

        Returns:
            int: Price precision.

        """
        return self.price_precision
  
    def set_exchange_rate(self, exchange_rate):
        """Set exchange rate.

        Args: 
            exchange_rate(float): Exchange rate.

        """
        self.exchange_rate = exchange_rate

    def get_exchange_rate(self):
        """Get exchange rate.

        Returns:
            float: Exchange rate.

        """
        return self.exchange_rate
  
    def set_line_items(self, line_item):
        """Set line items.

        Args:
            line_item(instance): Line item object.
  
        """
        self.line_items.append(line_item)
 
    def get_line_items(self):
        """Get line items.

        Returns:
            list of instance: List of line items object.

        """
        return self.line_items
  
    def set_sub_total(self, sub_total):
        """Set sub total.

        Args:
            sub_total(float): Sub total.

        """
        self.sub_total = sub_total

    def get_sub_total(self):
        """Get sub total.

        Returns:
            float: Sub total.

        """
        return self.sub_total

    def set_tax_total(self, tax_total):
        """Set tax total.

        Args:
            tax_total(float): Tax total.

        """
        self.tax_total = tax_total

    def get_tax_total(self):
        """Get tax total.
 
        Returns:
            tax_total(float): Tax total.

        """
        return self.tax_total
 
    def set_total(self, total):
        """Set total.

        Args:
            total(float): Total.

        """
        self.total = total

    def get_total(self):
        """Get total.

        Returns:
            float: Total.
   
        """
        return self.total
  
    def set_taxes(self, tax):
        """Set taxes.

        Args:
            tax(instance): Tax object.

        """
        self.taxes.append(tax)

    def get_taxes(self):
        """Get taxes.

        Returns:
            list of instance: List of tax object.

        """
        return self.taxes

    def set_payment_made(self, payment_made):
        """Set payment made.

        Args:
            payment_made(float): Payment made.

        """
        self.payment_made = payment_made
 
    def get_payment_made(self):
        """Get payment made.

        Returns:
            float: Payment made.

        """
        return self.payment_made
  
    def set_balance(self, balance):
        """Set balance.

        Args:
            balance(float): Balance.

        """
        self.balance = balance

    def get_balance(self):
        """Get balance.

        Returns:
            float: Balance.
 
        """
        return self.balance
  
    def set_billing_address(self, billing_address):
        """Set billling address,

        Args:
            billing_address(instance): Billing address object.

        """
        self.billing_address = billing_address

    def get_billing_address(self): 
        """Get billing address.

        Returns:
            instance: Billing address object.

        """
        return self.billing_address
  
    def set_payments(self, payments):  
        """Set payments.

        Args:
            payments(instance): Payments object.
 
        """
        self.payments.append(payment)

    def get_payments(self): 
        """Get payments.
 
        Returns:
            list of instance: List of payments object.

        """
        return self.payments
   
    def set_created_time(self, created_time):
        """Set created time.

        Args:
            created_time(str): Created time.

        """
        self.created_time = created_time
 
    def get_created_time(self):
        """Get created time.

        Returns:
            str: Created time.

        """
        return self.created_time

    def set_last_modified_time(self, last_modified_time):
        """Set last modified time.

        Args:
            last_modified_time(str): Last modified time.

        """
        self.last_modified_time = last_modified_time

    def get_last_modified_time(self):
        """Get last modified time.

        Returns:
            str: Last modified time.

        """
        return self.last_modified_time
  
    def set_reference_id(self, reference_id):
        """Set reference id.

        Args:
            reference_id(str): Reference id.

        """
        self.reference_id = reference_id
 
    def get_reference_id(self):
        """Get reference id.

        Returns: 
            str: Reference id.

        """
        return self.reference_id

    def set_notes(self, notes):
        """Set notes.

        Args:
            notes(str): Notes.

        """
        self.notes = notes

    def get_notes(self):
        """Get notes.

        Returns:
            str: Notes.

        """
        return self.notes
  
    def set_terms(self, terms):
        """Set terms.

        Args:
            terms(str): Terms.

        """
        self.terms = terms

    def get_terms(self): 
        """Get terms.

        Returns: 
            str: Terms.

        """
        return self.terms
 
    def set_attachment_name(self, attachment_name):
        """Set attachment name.

        Args:
            attachment_name(str): Attachment name.
 
        """
        self.attachment_name = attachment_name
 
    def get_attachment_name(self):
        """Get attachment name.

        Returns:
            str: Attachment name.

        """
        return self.attachment_name
   
    def set_account_id(self, account_id):
        """Set account id.

        Args:
            account_id(str): Account id.

        """
        self.account_id = account_id

    def get_account_id(self):
        """Get account id.
 
        Returns:
            str: Account id.

        """
        return self.account_id  
  
    def set_description(self, description):
        """Set description.

        Args:
            description(str): Description.

        """
        self.description = description

    def get_description(self): 
        """Get description.
 
        Returns:
            str: Description.

        """
        return self.description 
  
    def set_rate(self, rate):
        """Set rate.
 
        Args:
            rate(float): Rate.

        """
        self.rate = rate

    def get_rate(self): 
        """Get rate.

        Returns:
            float: Rate.

        """
        return self.rate

    def set_quantity(self, quantity):
        """Set quantity.

        Args:
            quantity(float): Quantity.

        """
        self.quantity = quantity

    def get_quantity(self):
        """Get quantity.

        Returns:
            float: Quantity.

        """   
        return self.quantity
  
    def set_tax_id(self, tax_id):
        """Set tax id.

        Args: 
            tax_id(str): Tax id.

        """
        self.tax_id = tax_id

    def get_tax_id(self):
        """Get tax id.

        Returns:
            str: Tax id.

        """
        return self.tax_id

    def set_due_days(self, due_days):
        """Set due days.

        Args:
            due_days(str): Due days.

        """
        self.due_days = due_days

    def get_due_days(self):
        """Get due days.

        Returns:
            str: Due days.
  
        """
        return self.due_days
    
    def to_json(self):
        """This method is used to convert bill object to json object.

        Returns:
            dict: Dictionary containing json object for Bills.

        """
        data = {}
        if self.bill_id != '': 
            data['bill_id'] = self.bill_id
        if self.amount_applied > 0: 
            data['amount_applied'] = self.amount_applied
        if self.vendor_id != '':
            data['vendor_id'] = self.vendor_id
        if self.is_inclusive_tax:
            data['is_inclusive_tax'] = self.is_inclusive_tax
        if self.bill_number != '':
            data['bill_number'] = self.bill_number
        if self.reference_number != '':
            data['reference_number'] = self.reference_number
        if self.date != '':
            data['date'] = self.date
        if self.due_date != '':
            data['due_date'] = self.due_date
        if self.exchange_rate > 0:
            data['exchange_rate'] = self.exchange_rate
        if self.line_items:
            data['line_items'] = []
            for value in self.line_items:
                line_item = value.to_json()
                data['line_items'].append(line_item)
        if self.notes != '':
            data['notes'] = self.notes
        if self.terms != '': 
            data['terms'] = self.terms
        return data
 




  





#$Id$

from books.model.PageContext import PageContext

class BillList: 
    """This class is used to create object for bill list."""
    def __init__(self):
        """Initialize parameters for bill list object."""
        self.bills = []
        self.page_context = PageContext()

    def set_bills(self, bills):
        """Set bills.
      
        Args:
            bills(instance): Bills object.
 
        """
        self.bills.append(bills)

    def get_bills(self):
        """Get bills.
 
        Returns:
            list of instance: List of bills object.
 
        """
        return self.bills

    def set_page_context(self, page_context):
        """Set page context.

        Args:
            page_context(instance): Page context object.

        """
        self.page_context = page_context

    def get_page_context(self):
        """Get page context.

        Returns:
            instance: Page context object.

        """
        return self.page_context

 




#$Id$

class BaseCurrencyAdjustment: 
    """This class is used to create object for Base Currency adjustment."""
    def __init__(self):
        """Initialize parameters for Base currency adjustment."""
        self.base_currency_adjustment_id = ''
        self.adjustment_date = ''
        self.exchange_rate = 0.0
        self.exchange_rate_formatted = ''
        self.currency_id = ''
        self.currency_code = ''
        self.notes = ''
        self.gain_or_loss = 0.0
        self.adjustment_date_formatted = ''
        self.accounts = []

    def set_base_currency_adjustment_id(self, base_currency_adjustment_id):
        """Set base currency adjustment id.

        Args:
            base_currency_adjustment_id(str): Base currency adjustment id.

        """
        self.base_currency_adjustment_id = base_currency_adjustment_id

    def get_base_currency_adjustment_id(self):
        """Get base currency adjustment id.

        Returns:
            str: Base currency adjustment id.

        """
        return self.base_currency_adjustment_id

    def set_adjustment_date(self, adjustment_date): 
        """Set adjustment date.

        Args:
            adjustment_date(str): Adjustment date.

        """ 
        self.adjustment_date = adjustment_date

    def get_adjustment_date(self): 
        """Get adjustment date.

        Returns:
            str: Adjustment date.

        """
        return self.adjustment_date

    def set_exchange_rate(self, exchange_rate):
        """Set exchaneg rate.

        Args:
            exchaneg_rate(float): Exchange rate.

        """
        self.exchange_rate = exchange_rate

    def get_exchange_rate(self):
        """Get exchange rate.

        Returns:
            float: Exchange rate.

        """
        return self.exchange_rate

    def set_exchange_rate_formatted(self, exchange_rate_formatted):
        """Set exchange rate formatted.

        Args: 
            exchange_rate_formatted(str): Exchange rate formatted.

        """
        self.exchange_rate_formatted = exchange_rate_formatted

    def get_exchange_rate_formatted(self):
        """Get exchange rate formatted.

        Returns:
            str: Exchange rate formatted.

        """
        return self.exchange_rate_formatted
    
    def set_currency_id(self, currency_id):
        """Set currency id.

        Args:
            currency_id(str): Currency id.

        """
        self.currency_id = currency_id

    def get_currency_id(self):
        """Get currency id.

        Returns: 
            str: Currency id.

        """
        return self.currency_id

    def set_currency_code(self, currency_code):
        """Set currency code.

        Args:
            currency_code(str): Currency code.

        """
        self.currency_code = currency_code

    def get_currency_code(self): 
        """Get currecny code.

        Returns:  
            str: Currency code.

        """
        return self.currency_code

    def set_notes(self, notes):
        """Set notes.
 
        Args:
            notes(str): Notes.

        """
        self.notes = notes

    def get_notes(self):
        """Get notes.

        Returns: 
            str: Notes.

        """
        return self.notes
    
    def set_gain_or_loss(self, gain_or_loss):
        """Set gain or loss.

        Args:
            gain_or_loss(float): Gain or loss.

        """
        self.gain_or_loss = gain_or_loss

    def get_gain_or_loss(self):
        """Get gain or loss.

        Returns:
            float: Gain or loss.

        """
        return self.gain_or_loss

    def set_adjustment_date_formatted(self, adjustment_date_formatted):
        """Set adjustment date formatted.

        Args:
            adjustment_date_formatted(str): Adjustment date formatted.

        """
        self.adjustment_date_formatted = adjustment_date_formatted

    def get_adjustment_date_foramtted(self):
        """Get adjustment date formatted.

        Returns: 
            str: Adjustment date formatted.

        """
        return self.adjustment_date_formatted

    def set_accounts(self, accounts):
        """Set accounts.

        Args:
            accounts(instance): Accounts.

        """
        self.accounts.append(accounts)

    def get_accounts(self):
        """Get accounts.

        Returns:
            instance: Accounts.

        """
        return self.accounts

    def to_json(self):
        """This method is used to convert base currency adjusment object in json format.

        Returns:
            dict: Dictionary containing json object for base currency adjustment.

        """
        data = {}
        if self.currency_id != '':
            data['currency_id'] = self.currency_id
        if self.adjustment_date != '':
            data['adjustment_date'] = self.adjustment_date
        if self.exchange_rate > 0:
            data['exchange_rate'] = self.exchange_rate
        if self.notes != '':
            data['notes'] = self.notes
        return data



#$Id$#

from books.util.ZohoHttpClient import ZohoHttpClient
from books.parser.BankAccountsParser import BankAccountsParser
from books.api.Api import Api
from json import dumps

base_url = Api().base_url + 'bankaccounts/'
zoho_http_client  =  ZohoHttpClient()
parser  =  BankAccountsParser()

class BankAccountsApi:
    """Bank Accounts Api is used to 
    
    1.List all bank and credit card accounts of the organization.
    2.Get detailed look of a specified account.
    3.Create a bank account or a credit card account for an organization.
    4.Modify an existing account.
    5.Delete an existing bank account from an organization.
    6.Make an account inactive.
    7.Make an account active.
    8.Get the details of last imported statement.
    9.Delete the statement that was imported lastly.

    """
    def __init__(self, authtoken, organization_id):
        """Initialize Bank accounts api using user's authtoken and 
            organization id.
        
        Args: 
            authotoken(str): Authtoken.
            organization id(str): Organization id.

        """

        self.details = {
            'authtoken': authtoken, 
            'organization_id': organization_id
            }
  
    def get_bank_accounts(self, parameter=None):
        """List all bank and credit accounts of an organization.
       
        Args:
            parameter(dict, optional): Filter with which the list has to be
                displayed. Defaults to None.

        Returns:
            instance: Bank accounts list object.

        """
        resp = zoho_http_client.get(base_url, self.details, parameter)
        return parser.get_list(resp) 

    def get(self, account_id):
        """Get bank account details.

        Args:
            account_id(str): Account id.

        Returns:
            instance: Bank accouts object.

        """
        url = base_url + account_id
        resp = zoho_http_client.get(url, self.details)
        return parser.get_account_details(resp) 

    def create(self, bank_account):
        """Create a bank account.
 
        Args: 
            bank_account(instance): Bank accounts object.
 
        Returns:
            instance: Bank accounts object.

        """
        json_object = dumps(bank_account.to_json())
        data = {
            'JSONString': json_object
            }
        resp = zoho_http_client.post(base_url, self.details, data)
        return parser.get_account_details(resp) 

    def update(self, account_id, bank_account):
        """Update an existing bank account.

        Args:
            account_id(str): Account id.
            bank_account(instance): Bank account object.

        Returns:
            instance: Bank account object.

        """
        url = base_url + account_id
        json_object = dumps(bank_account.to_json())
        data = {
            'JSONString': json_object
            }
        resp = zoho_http_client.put(url, self.details, data)
        return parser.get_account_details(resp)     

    def delete(self, account_id):
        """Delete an existing bank account.
 
        Args:
            account_id(str): Account id.

        Returns:
            str: Success message('The account has been deleted.').

        """
        url = base_url + account_id
        resp = zoho_http_client.delete(url, self.details)
        return parser.get_message(resp) 

    def deactivate_account(self, account_id):
        """Deactivate a bank account.

        Args:
            account_id(str): Account id.
 
        Returns:
            str: Success message('The account has been marked as inactive.').
         
        """
        url = base_url + account_id + '/inactive'
        data = {
            'JSONString': ''
            }
        resp = zoho_http_client.post(url, self.details, data)
        return parser.get_message(resp) 

    def activate_account(self, account_id):
        """Activate a bank account.

        Args:
            account_id(str): Account id.

            str: Success message('The account has been marked as active.').

        """
        url = base_url + account_id + '/active'
        data = {
            'JSONString': ''
            }
        resp = zoho_http_client.post(url, self.details, data)
        return parser.get_message(resp) 

    def get_last_imported_statement(self, account_id):
        """Get the details of previously imported statement for the account.

        Args: 
            account_id(str): Account id.

        Returns:
            instance: Statement object.

        """ 
        url = base_url + account_id + '/statement/lastimported'
        resp = zoho_http_client.get(url, self.details)
        return parser.get_statement(resp) 
   
    def delete_last_imported_statement(self, account_id, statement_id):
        """Delete the statement that was previously imported.

        Args:
            account_id(str): Account id.
            statement_id(str): Statement id.

        Returns:
            str: Success message('You have successfully deleted the last imported 
                 statement.').

        Raises:
            Books Exception: If status is not '200' or '201'.

        """
        url = base_url + account_id + '/statement/' + statement_id
        resp = zoho_http_client.delete(url, self.details)
        return parser.get_message(resp) 

 
  



#$Id$

class BankAccount:
    """This class is used to create object for Bank accounts."""
    def __init__(self):
        """Initialize parameters for Bank accounts object."""
        self.account_id = ''
        self.account_name = ''
        self.currency_id = ''
        self.currency_code = ''
        self.account_type = ''
        self.account_number = ''
        self.uncategorized_transactions = ''
        self.is_active = None
        self.balance = 0.0
        self.bank_name = ''
        self.routing_number = ''
        self.is_primary_account = None
        self.is_paypal_account = None
        self.paypal_email_address = ''
        self.description = ''
        self.paypal_type = ''
 
    def set_account_id(self, account_id):
        """Set account id.

        Args:
            account_id(str): Account id.

        """
        self.account_id = account_id

    def get_account_id(self):
        """Get account id.

        Returns:
            str: Account id.

        """
        return self.account_id

    def set_account_name(self, account_name):
        """Set account name.

        Args:
            account_name(str): Account name.

        """
        self.account_name = account_name

    def get_account_name(self):
        """Get account name.

        Returns:
            str: Account name.

        """
        return self.account_name
   
    def set_currency_id(self, currency_id):
        """Set currency id.

        Args:
            currency_id(str): Currency id.

        """
        self.currency_id = currency_id

    def get_currency_id(self):
        """Get currency id.

        Returns:
            str: Currency id.

        """
        return self.currency_id

    def set_currency_code(self, currency_code): 
        """Set currecny code.

        Args: 
            currency_code(str): Currency code.

        """
        self.currency_code = currency_code

    def get_currency_code(self):
        """Get currency code.

        Returns: 
            str: Currency code.

        """
        return self.currency_code
 
    def set_account_type(self, account_type):
        """Set account type.

        Args:
            account_type(str): Account type.

        """
        self.account_type = account_type

    def get_account_type(self):
        """Get account type.

        Returns:
            str: Account type.

        """
        return self.account_type

    def set_account_number(self, account_number):
        """Set account number.

        Args:
            account_number(str): ACcount number.

        """
        self.acccount_number = account_number

    def get_account_number(self):
        """Get account number.

        Returns: 
            str: Account number.

        """
        return self.account_number

    def set_uncategorized_transactions(self, uncategorized_transactions):
        """Set uncategorized transactions.

        Args:
            uncategorized_transactions(str): Uncategorized transactions.

        """
        self.uncategorized_transactions = uncategorized_transactions

    def get_uncategorized_transactions(self):
        """Get uncategorized transactions.

        Returns:
            str: Uncategorized transactions.

        """
        return self.uncategorized_transactions

    def set_is_active(self, is_active): 
        """Set whether the account is active or not.
 
        Args:
            is_active(bool): True if it is active else False.

        """
        self.is_active = is_active

    def get_is_active(self):
        """Get whether the bank account is active or not.

        Returns:
            bool: True if active else False.

        """
        return self.is_active

    def set_balance(self, balance):
        """Set balance.

        Args:
            balance(float): Balance.

        """
        self.balance = balance

    def get_balance(self): 
        """Get balance.

        Returns:
            float: Balance.

        """
        return self.balance

    def set_bank_name(self, bank_name):
        """Set bank name.

        Args:
            bank_name(str): Bank name.

        """
        self.bank_name = bank_name

    def get_bank_name(self):
        """Get bank name.

        Returns:
            str: Bank name.

        """
        return self.bank_name 
 
    def set_routing_number(self, routing_number):
        """Set routing number.

        Args:
            routing_number(str): Routing number.

        """
        self.routing_number = routing_number

    def get_routing_number(self): 
        """Get routing number.

        Returns:
            str: Routing number.

        """
        return self.routing_number

    def set_is_primary_account(self, is_primary_account):
        """Set whether the bank account is primary account or not.
   
        Args:
            is_primary_account(bool): True if it is primary account else False.

        """
        self.is_primary_account = is_primary_account

    def get_is_primary_account(self):
        """Get whether the bank account is primary account or not.

        Returns:
            bool: True if it is primary account else False.

        """
        return self.is_primary_account

    def set_is_paypal_account(self, is_paypal_account): 
        """Set whether the account is paypal account.

        Args:
            is_paypal_account(bool): True if the account is paypal account.

        """
        self.is_paypal_account = is_paypal_account

    def get_is_paypal_account(self): 
        """Get whether the account is paypal account.

        Returns:
            bool: True if the account is paypal account else False.

        """
        return self.is_paypal_account
 
    def set_paypal_email_address(self, paypal_email_address):
        """Set paypal email address.

        Args:
            paypal_email_Address(str): Paypal email address.

        """
        self.paypal_email_address = paypal_email_address

    def get_paypal_email_address(self):
        """Get paypal email address.

        Returns:
            str: PAypal email address.
 
        """
        return self.paypal_email_address

   
 
    def set_description(self, description):
        """Set description.

        Args:
            description(str): Description.

        """
        self.descrition = description
 
    def get_description(self):
        """Get description.

        Returns:  
            str: Description.

        """
        return self.description

    def set_paypal_type(self, paypal_type):
        """Set paypal type.

        Args:
            paypal_type(str): Paypal type.

        """
        self.paypal_type = paypal_type

    def get_paypal_type(self):
        """Get paypal type.

        Returns:
            str: Paypal type.

        """
        return self.paypal_type

    def to_json(self):
        """This method is used to create json object for bank acoounts.
        
        Returns:
            dict: Dictionary containing json object for bank accounts.

        """
        data = {}
        if self.account_name != '':
            data['account_name'] = self.account_name
        if self.account_type != '':
            data['account_type'] = self.account_type
        if self.account_number != '':
            data['account_number'] = self.account_number
        if self.currency_id != '':
            data['currency_id'] = self.currency_id
        if self.description != '':
            data['description'] = self.description
        if self.bank_name != '':
            data['bank_name'] = self.bank_name
        if self.routing_number != '':
            data['routing_number'] = self.routing_number
        if self.is_primary_account is not None:
            data['is_primary_account'] = self.is_primary_account
        if self.is_paypal_account is not None:
            data['is_paypal_account'] = self.is_paypal_account
        if self.paypal_type != '':
            data['paypal_type'] = self.paypal_type
        if self.paypal_email_address != '':
            data['paypal_email_address'] = self.paypal_email_address
        return data



#$Id$#

from books.model.BankRule import BankRule
from books.model.BankRuleList import BankRuleList
from books.model.Criteria import Criteria

class BankRulesParser:
    """This class is used to parse the json response for Bank rules."""
  
    def get_rules(self, resp):
        """This method parses the given response and returns list of bank 
            rules object.

        Args:
            resp(dict): Dictionary containing json object for bank rules.

        Returns:
            list of instance: List of Bank rules object.

        """
        bank_rules = BankRuleList()
        for value in resp['rules']:
            bank_rule = BankRule()
            bank_rule.set_rule_id(value['rule_id'])
            bank_rule.set_rule_name(value['rule_name'])
            bank_rule.set_rule_order(value['rule_order'])
            bank_rule.set_apply_to(value['apply_to'])
            bank_rule.set_criteria_type(value['criteria_type'])
            bank_rule.set_record_as(value['record_as'])
            bank_rule.set_account_id(value['account_id'])
            bank_rule.set_account_name(value['account_name'])
            for criteria_value in value['criterion']:
                criteria = Criteria()
                criteria.set_criteria_id(criteria_value['criteria_id'])
                criteria.set_field(criteria_value['field'])
                criteria.set_comparator(criteria_value['comparator'])
                criteria.set_value(criteria_value['value'])
                bank_rule.set_criterion(criteria)
            bank_rules.set_bank_rules(bank_rule)
        return bank_rules

    def get_rule(self, resp):
        """This method parses the given response and returns bank rule object.

        Args:
            resp(dict): Dictionary containing json object for bank rules.

        Returns:  
            instance: Bank rules object.

        """
        bank_rule = BankRule()
        rule = resp['rule']
        bank_rule.set_rule_id(rule['rule_id'])
        bank_rule.set_rule_name(rule['rule_name'])
        bank_rule.set_rule_order(rule['rule_order'])
        bank_rule.set_apply_to(rule['apply_to'])
        bank_rule.set_criteria_type(rule['criteria_type'])
        bank_rule.set_record_as(rule['record_as'])
        for value in rule['criterion']:
            criteria = Criteria()
            criteria.set_criteria_id(value['criteria_id'])  
            criteria.set_field(value['field'])
            criteria.set_comparator(value['comparator'])
            criteria.set_value(value['value'])
            bank_rule.set_criterion(criteria)
        bank_rule.set_account_id(rule['account_id'])
        bank_rule.set_account_name(rule['account_name'])
        bank_rule.set_tax_id(rule['tax_id'])
        bank_rule.set_customer_id(rule['customer_id'])
        bank_rule.set_customer_name(rule['customer_name'])
        bank_rule.set_reference_number(rule['reference_number'])
        return bank_rule

    def get_message(self, resp):
        """This method parses the given response and returns message string.

        Args:
            resp(dict): Dictionary containing json object for message.

        Returns: 
            str: Success message.

        """
        return resp['message']




#$Id$

from books.model.Term import Term
from books.model.AddressFormat import AddressFormat

class Preference:
    """This class is used to create object for preferences."""
    def __init__(self):
        """Initialize parameters for Preferences object."""
        self.convert_to_invoice = None
        self.attach_pdf_for_email = ''
        self.estimate_approval_status = ''
        self.notify_me_on_online_payment = None
        self.send_payment_receipt_acknowledgement = None
        self.auto_notify_recurring_invoice = None
        self.snail_mail_include_payment_stub = None
        self.is_show_powered_by = None
        self.attach_expense_receipt_to_invoice = None
        self.is_estimate_enabled = None
        self.is_project_enabled = None
        self.is_purchaseorder_enabled = None
        self.is_salesorder_enabled = None
        self.is_salesorder_enabled = None
        self.is_pricebooks_enabled = None
        self.attach_payment_receipt_with_acknowledgement = None
        self.auto_reminders = []
        self.terms = Term()
        self.address_formats = AddressFormat()
        self.allow_auto_categorize = ''
   
    def set_allow_auto_categorize(self, allow_auto_categorize):
        """Set allow auto categorize.

        Args:
            allow_auto_categorize(str): Allow auto categorize.

        """
        self.allow_auto_categorize = allow_auto_categorize

    def get_allow_auto_categorize(self):
        """Get allow auto categorize.

        Returns:
            str: Allow auto categorize.

        """
        return self.allow_auto_categorize

    def set_convert_to_invoice(self, convert_to_invoice):
        """Set whether to convert to invoice.
 
        Args:
            convert_to_invoice(bool): True to Convert to invoice else False.

        """
        self.convert_to_invoice = convert_to_invoice

    def get_convert_to_invoice(self):
        """Get whether to convert to invoice.

        Returns:
            bool: True to Convert to invoice else false.
        """
        return self.convert_to_invoice

    def set_attach_pdf_for_email(self, attach_pdf_for_email):
        """Set whether to attach pdf for email.

        Args:
            attach_pdf_for_email(bool): True to attach pdf for email.

        """
        self.attach_pdf_for_email = attach_pdf_for_email

    def get_attach_pdf_for_email(self):
        """Get whether to attach pdf for email.

        Returns:
            bool: True to attach pdf for email.

        """
        return self.attach_pdf_for_email 

    def set_estimate_approval_status(self, estimate_approval_status):
        """Set estimate approval status.

        Args:
            estimate_approval_status(bool): Estimate approval status.

        """
        self.estimate_approval_status = estimate_approval_status

    def get_estimate_approval_status(self):
        """Get estimate approval status.

        Returns:
            bool: Estimate approval status.

        """
        return self.estimate_approval_status

    def set_notify_me_on_online_payment(self, notify_me_on_online_payment):
        """Set whether to notify me on online payment.

        Args:
            notify_me_on_online(bool): True to notify online payment else 
                false.

        """
        self.notify_me_on_online_payment = notify_me_on_online_payment

    def get_notify_me_on_online_payment(self):
        """Get whether to notify me on online payment.

        Returns:
            bool: True to notify online payment else False.

        """
        return self.notify_me_on_online_payment

    def set_send_payment_receipt_acknowledgement(self, \
        send_payment_receipt_acknowledgement):
        """Set whether to send payment receipt acknowledgement.

        Args:
            send_payment_receipt_acknowledgement(bool): True to send payment 
                receipt acknowledgemnt else False.

        """
        self.send_payment_receipt_acknowledgement = \
             send_payment_receipt_acknowledgement

    def get_send_payment_receipt_acknowledgement(self):
        """Get whether to send payment receipt acknowledgement.

        Returns:
            bool: True to send payment receipt acknowledgemnt else False.

        """
        return self.send_payment_receipt_acknowledgement

    def set_auto_notify_recurring_invoice(self, auto_notify_recurring_invoice):
        """Set whether to notify invoice automatically or not.

        Args:
            auto_notify_recurring_invoice(bool): True to auto notify recurring 
                invoice else false.
 
        """
        self.auto_notify_recurring_invoice = auto_notify_recurring_invoice

    def get_auto_notify_recurring_invoice(self):
        """Get whether to notify invoice automatically or not.

        Returns: 
            bool: True if auto notify is enabled else false.

        """
        return self.auto_notify_recurring_invoice

    def set_snail_mail_include_payment_stub(self, \
        snail_mail_include_payment_stub):
        """Set snail mail include payment stub.

        Args:
            snail_mail_include_payment_stub(bool): Snail mail paymanet stub.

        """
        self.snail_mail_include_payment_stub = snail_mail_include_payment_stub

    def get_snail_mail_include_payment_stub(self):
        """Get snail mail payment include stub.

        Returns: 
            bool: Snail mail payment include stub.

        """
        return self.snail_mail_include_payment_stub

    def set_is_show_powered_by(self, is_show_powered_by):
        """Set whether to show powered by.

        Args:
            is_show_powered_by(bool): True to show powered by.

        """
        self.is_show_powered_by = is_show_powered_by

    def get_is_show_powered_by(self):
        """Get whether to show powered by.

        Returns:
            bool: True to show powered by else false.

        """
        return self.is_show_powered_by
 
    def set_attach_expense_receipt_to_invoice(self, attach_receipt_to_invoice):
        """Set whether to attach receipt to invoice.

        Args:
            attach_receipt_to_invoice(bool): True to attach receipt to invoice.

        """
        self.attach_expense_receipt_to_invoice = attach_receipt_to_invoice

    def get_attach_expense_receipt_to_invoice(self):
        """Get whether to attach receipt to invoice.

        Returns:
            bool: True to attach receipt to invoice.

        """
        return self.attach_expense_receipt_to_invoice

    def set_is_estimate_enabled(self, is_estimate_enabled):
        """Set whether to enable estimate or not.

        Args:
            is_estimate_enabled(bool): True to enable estimate else False.

        """ 
        self.is_estimate_enabled = is_estimate_enabled

    def get_is_estimate_enabled(self): 
        """Get whether to enable estimate or not.

        Returns:
            bool: True to enable estimate else false.

        """
        return self.is_estimate_enabled

    def set_is_project_enabled(self, is_project_enabled):
        """Set whether to enable project or not.

        Args:
            is_project_enabled(bool): True to enable project else False.

        """
        self.is_project_enabled = is_project_enabled

    def get_is_project_enabled(self):
        """Get whether to enable project or not.

        Returns:
            bool: True to enable project else False.

        """
        return self.is_project_enabled

    def set_is_purchaseorder_enabled(self, is_purchaseorder_enabled):
        """Set whether is purchaseorder enabled.

        Args:
            is_purchaseorder_enabled(bool):True if purchase order is enabled 
                 else false.

        """
        self.is_purchaseorder_enabled = is_purchaseorder_enabled

    def get_is_purchaseorder_enabled(self):
        """Get whether is purchase order enabled.

        Returns:
            bool: True if purchase order is enabled else false.

        """
        return self.is_purchaseorder_enabled

    def set_is_salesorder_enabled(self, is_salesorder_enabled):
        """Set whether salesorder is enabled.

        Args:
            is_salesorder_enabled(bool): True if salesorder is enabled else 
                false.

        """
        self.is_salesorder_enabled = is_salesorder_enabled

    def get_is_salesorder_enabled(self):
        """Get whether salesorder is enabled.

        Returns:
            bool: True if sales order is enabled else false.

        """
        return self.is_salesorder_enabled

    def set_is_pricebooks_enabled(self, is_pricebooks_enabled):
        """Set is pricebooks enabled.

        Args:
            is_pricebooks_enabled(bool): True if pricebooks is enabled else 
                false.

        """
        self.is_pricebooks_enabled = is_pricebooks_enabled

    def get_is_pricebooks_enabled(self):
        """Get is pricebooks enabled.

        Returns:
            bool: True if price books is enabled else false.

        """
        return self.is_pricebooks_enabled

    def set_attach_payment_receipt_with_acknowledgement(self, \
        attach_payment_receipt_with_acknowledgement):
        """Set attachpayment receipt with acknowledgemnt.

        Args:
            attach_payment_receipt_with_acknowledgement(bool): True to attach 
                payment receipt with acknowledgemnt.

        """
        self.attach_payment_receipt_with_acknowledgement = \
            attach_payment_receipt_with_acknowledgement

    def get_attach_payment_receipt_with_acknowledgemnt(self):
        """Get attach payment receipt with acknowledgement.

        Returns:
            bool: True to attach payment receipt with acknowledgment.

        """
        return self.attach_payment_receipt_with_acknowledgement

    def set_auto_reminders(self, auto_reminder):
        """Set auto reminders.

        Args:
            auto_reminder(instance): Auto reminders.

        """
        self.auto_reminders.append(auto_reminder)

    def get_auto_reminders(self): 
        """Get auto reminders.

        Returns:
            list of instance: List of auto reminder object.

        """
        return self.auto_reminders

    def set_terms(self, term):
        """Set terms.

        Args:
            term(instance): Terms object.

        """
        self.terms = term

    def get_terms(self):
        """Get terms.

        Returns:
            instance: Term object.

        """
        return self.terms

    def set_address_formats(self, address_formats):
        """Set address formats.

        Args:
            address_formats(instance): Address Formats.

        """
        self.address_formats = address_formats

    def get_address_formats(self):
        """Get address formats.

        Returns:
            instance: Address formats.

        """
        return self.address_formats

    def to_json(self):
        """This method is used to convert preference object to json format.

        Returns:
            dict: Dictionary containing json object for preferences.

        """
        data = {}
        if self.convert_to_invoice is not None:
            data['convert_to_invoice'] = self.convert_to_invoice
        if self.notify_me_on_online_payment is not None:
            data['notify_me_on_online_payment'] = \
                self.notify_me_on_online_payment
        if self.send_payment_receipt_acknowledgement is not None:
            data['send_payment_receipt_acknowledgement'] = \
                self.send_payment_receipt_acknowledgement
        if self.auto_notify_recurring_invoice is not None:
            data['auto_notify_recurring_invoice'] = \
                self.auto_notify_recurring_invoice
        if self.snail_mail_include_payment_stub != None:
            data['snail_mail_include_payment_stub'] = \
                self.snail_mail_include_payment_stub
        if self.is_show_powered_by != None: 
            data['is_show_powered_by'] = self.is_show_powered_by
        if self.attach_expense_receipt_to_invoice != None:
            data['attach_expense_receipt_to_invoice'] = \
                self.attach_expense_receipt_to_invoice
        if self.is_estimate_enabled != None:
            data['is_estimate_enabled'] = self.is_estimate_enabled
        if self.is_project_enabled != None:
            data['is_project_enabled'] = self.is_project_enabled
        return data



#$Id$

from books.model.PageContext import PageContext

class RecurringExpenseList:
    """This class is used to create object for recurring expenses list."""
    def __init__(self):
        """Initialize parameters for recurring expenses list object."""
        self.recurring_expenses = []
        self.page_context = PageContext()
 
    def set_recurring_expenses(self, recurring_expenses):
        """Set recurring expenses.

        Args:
            recurring_expenses(instance): Recurring expenses object.

        """
        self.recurring_expenses.append(recurring_expenses)
 
    def get_recurring_expenses(self):
        """Get recurring expenses.

        Returns:
            list of instance: List of recurring expenses object.

        """
        return self.recurring_expenses

    def set_page_context(self, page_context):
        """Set page context.

        Args:
            page_context(instance): Page context object.

        """
        self.page_context = page_context

    def get_page_context(self):
        """Get page context.

        Returns:
            instance: Page context object.

        """
        return self.page_context





#$Id$

class Project: 
    """This class is used to create object for Projects."""
    def __init__(self): 
        """Initialize the parameters for projects object."""
        self.project_id = ''
        self.project_name = ''
        self.customer_id = ''
        self.customer_name = ''
        self.currency_code = '' 
        self.description = ''
        self.status = ''
        self.billing_type = ''
        self.rate = 0.0
        self.budget_type = ''
        self.budget_hours = 0
        self.budget_amount = 0.0
        self.total_hours = ''
        self.billed_hours = ''
        self.un_billed_hours = ''
        self.created_time = ''
        self.tasks = []
        self.users = []

    def set_project_id(self, project_id):
        """Set project_id.

        Args:
            project_id(str): Project id.

        """
        self.project_id = project_id

    def get_project_id(self):
        """Get project id.

        Returns:
            str: Project id.
 
        """
        return self.project_id

    def set_project_name(self, project_name):
        """Set project name.

        Args:
            project_name(str): Project name.

        """
        self.project_name = project_name

    def get_project_name(self):
        """Get project name.

        Returns: 
            str: Project name.

        """
        return self.project_name

    def set_customer_id(self, customer_id):
        """Set customer id.

        Args:
            customer_id(str): Customer id.

        """
        self.customer_id = customer_id

    def get_customer_id(self):
        """Get customer id.

        Returns:
            str: Customer id.

        """
        return self.customer_id

    def set_customer_name(self, customer_name):
        """Set customer name.

        Args:
            customer_name(str): Customer name.
 
        """
        self.customer_name = customer_name

    def get_customer_name(self):
        """Get customer name.

        Returns:
            str: Customer name.

        """
        return self.customer_name

    def set_currency_code(self, currency_code):
        """Set currency code.

        Args:
            currency_code(str): Currency code.

        """
        self.currency_code = currency_code

    def get_currency_code(self): 
        """Get currency_code.

        Returns: 
            str: Currency code.

        """
        return self.currency_code

    def set_description(self, description):
        """Set description.

        Args:
            description(str): Description.

        """ 
        self.description = description

    def get_description(self):
        """Get description.

        Returns:
            str: Description.

        """
        return self.description

    def set_status(self, status):
        """Set status.

        Args:
            status(str): Status.

        """
        self.status = status

    def get_status(self):
        """Get status.

        Returns:
            str: Status.

        """
        return self.status

    def set_billing_type(self, billing_type):
        """Set billing type.

        Args:
            billing_type(str): Billing type.

        """
        self.billing_type = billing_type

    def get_billing_type(self):
        """Get billing type.

        Returns:
            str: Billing type.

        """
        return self.billing_type

    def set_budget_type(self, budget_type):
        """Set budget type.

        Args:
            budget_type(str): Budget type.

        """
        self.budget_type = budget_type

    def get_budget_type(self):
        """Get budget type.

        Returns:
            str: Budget type.

        """
        return self.budget_type

    def set_total_hours(self, total_hours):
        """Set total hours.

        Args:
            total_hours(str): Total hours.

        """
        self.total_hours = total_hours

    def get_total_hours(self):
        """Get total hours.

        Returns:
            str: Total hours.

        """
        return self.total_hours

    def set_billed_hours(self, billed_hours):
        """Set billed hours.

        Args:
            billed_hours(str): Billed hours.

        """
        self.billed_hours = billed_hours

    def get_billed_hours(self):
        """Get billed hours.

        Returns:
            str: Billed hours.

        """
        return self.billed_hours

    def set_un_billed_hours(self, un_billed_hours): 
        """Set unbilled hours.

        Args:
            un_billed_hours(str): Unbilled hours.

        """
        self.un_billed_hours = un_billed_hours

    def get_un_billed_hours(self):
        """Get unbilled hours.

        Returns:
            str: Unbilled hours.

        """
        return self.un_billed_hours

    def set_created_time(self, created_time):
        """Set created time.

        Args:
            created_time(str): Created time.

        """
        self.created_time = created_time

    def get_created_time(self):
        """Get created time.

        Returns:
            str: Created time.

        """
        return self.created_time

    def set_tasks(self, task):
        """Set task.

        Args:
            task(instance): Task object.

        """
        self.tasks.append(task)

    def get_tasks(self):
        """Get tasks.

        Returns:
            list of instance: List of task object.

        """
        return self.tasks

    def set_users(self, user):
        """Set User.

        Args:
            user(instance): User object.

        """
        self.users.append(user)

    def get_users(self):
        """Get user.

        Returns:
            list of object: User object.

        """
        return self.users

    def set_rate(self, rate):
        """Set rate.

        Args:
            rate(float): Rate.

        """
        self.rate = rate

    def get_rate(self):
        """Get rate.

        Returns:
            float: Rate.

        """
        return self.rate

    def set_budget_hours(self, budget_hours):
        """Set budget hours.

        Args:
            budget_hours(str): Budget hours.

        """
        self.budget_hours = budget_hours

    def get_budget_hours(self):
        """Get budget hours.

        Returns:
            str: Budget hours.

        """
        return self.budget_hours

    def set_budget_amount(self, budget_amount):
        """Set budget amount.

        Args:
            budget_amount(float): Budget amount.

        """
        self.budget_amount = budget_amount

    def get_budget_amount(self):
        """Get budget amount.

        Returns:
            float: Budget amount.

        """
        return self.budget_amount

    def to_json(self):
        """This method is used to convert projects object to json format.

        Returns:
            dict: Dictionary containing json for projects.

        """
        data = {}
        if self.project_name != '':
            data['project_name'] = self.project_name
        if self.customer_id != '':
            data['customer_id'] = self.customer_id
        if self.description != '':
            data['description'] = self.description
        if self.billing_type != '':
            data['billing_type'] = self.billing_type
        if self.rate > 0:
            data['rate'] = self.rate
        if self.budget_type != '':
            data['budget_type'] = self.budget_type
        if self.budget_hours != '':
            data['budget_hours'] = self.budget_hours
        if self.budget_amount > 0:
            data['budget_amount'] = self.budget_amount
        if self.users:
            data['users'] = []
            print(self.users)
            for value in self.users:
                print(value)
                user = value.to_json()
                data['users'].append(user)
        if self.tasks:
            data['tasks'] = []
            for value in self.tasks:
                task = value.to_json()
                data['tasks'].append(task)
        return data



#$Id$#

from books.model.VendorPayment import VendorPayment
from books.model.VendorPaymentList import VendorPaymentList
from books.model.Bill import Bill

class VendorPaymentsParser:
    """This class is used to parse the json response for Vendor payments."""

    def get_list(self, resp):
        """This method parses the given response and returns vendor payments 
            list object.

        Args:
            resp(dict): Dictionary containing json object for vendor payments 
                list.

        Returns:
            instance: Vendor payments list object.

        """
        vendor_payments_list = VendorPaymentList()
        for value in resp['vendorpayments']:
            vendor_payment = VendorPayment()
            vendor_payment.set_payment_id(value['payment_id'])
            vendor_payment.set_vendor_id(value['vendor_id'])
            vendor_payment.set_vendor_name(value['vendor_name'])
            vendor_payment.set_payment_mode(value['payment_mode'])
            vendor_payment.set_description(value['description'])
            vendor_payment.set_date(value['date'])
            vendor_payment.set_reference_number(value['reference_number'])
            vendor_payment.set_exchange_rate(value['exchange_rate'])
            vendor_payment.set_amount(value['amount'])
            vendor_payment.set_paid_through_account_id(value[\
            'paid_through_account_id'])
            vendor_payment.set_paid_through_account_name(value[\
            'paid_through_account_name'])
            vendor_payment.set_balance(value['balance'])
            vendor_payments_list.set_vendor_payments(vendor_payment)
        return vendor_payments_list

    def get_vendor_payment(self, resp):
        """This method is used to parse the given response and returns vendor 
            payments object.

        Args: 
            resp(dict): Dictionary containing json object for vendor payments.

        Returns:
            instance: Vendor payments object.

        """
        vendor_payment_obj = VendorPayment()
        vendor_payment = resp['vendorpayment']
        vendor_payment_obj.set_payment_id(vendor_payment['payment_id'])
        vendor_payment_obj.set_vendor_id(vendor_payment['vendor_id'])
        vendor_payment_obj.set_vendor_name(vendor_payment['vendor_name'])
        vendor_payment_obj.set_payment_mode(vendor_payment['payment_mode'])
        vendor_payment_obj.set_description(vendor_payment['description'])
        vendor_payment_obj.set_date(vendor_payment['date'])
        vendor_payment_obj.set_reference_number(vendor_payment[\
        'reference_number'])
        vendor_payment_obj.set_exchange_rate(vendor_payment['exchange_rate'])
        vendor_payment_obj.set_amount(vendor_payment['amount'])
        vendor_payment_obj.set_currency_symbol(vendor_payment[\
        'currency_symbol'])
        vendor_payment_obj.set_paid_through_account_id(vendor_payment[\
        'paid_through_account_id'])
        vendor_payment_obj.set_paid_through_account_name(vendor_payment[\
        'paid_through_account_name'])
        for value in vendor_payment['bills']:
            bill = Bill()
            bill.set_bill_number(value['bill_number'])
            bill.set_bill_payment_id(value['bill_payment_id'])
            bill.set_bill_id(value['bill_id'])
            bill.set_total(value['total'])
            bill.set_balance(value['balance'])
            bill.set_amount_applied(value['amount_applied'])
            bill.set_date(value['date'])
            bill.set_due_date(value['due_date'])
            vendor_payment_obj.set_bills(bill)
        return vendor_payment_obj

    def get_message(self, resp):
        """This message parses the given response and returns message string.
    
        Args:
            resp(dict): Response containing json object for message.

        Returns:
            str: Success message.

        """
        return resp['message']
       



#$Id$

class Comment:
    """This class is used to create object for comments."""
    def __init__(self):
        """Initialize parameters for comments."""
        self.comment_id = ''
        self.contact_id = ''
        self.contact_name = ''
        self.description = ''
        self.commented_by_id = ''
        self.commented_by = ''
        self.date = ''
        self.date_description = ''
        self.time = ''
        self.transaction_id = ''
        self.transaction_type = ''
        self.is_entity_deleted = None
        self.operation_type = ''
        self.estimate_id = ''
        self.comment_type = ''
        self.invoice_id = ''
        self.payment_expected_date = ''
        self.show_comment_to_clients = None
        self.recurring_invoice_id = ''
        self.creditnote_id = ''
        self.expense_id = ''
        self.recurring_expense_id = ''
        self.bill_id = ''
        self.project_id = ''
        self.is_current_user = None

    def set_is_current_user(self, is_current_user):
        """Set whether it is current user or not.

        Args:
            is_current_user(bool): True if it is current user else false.

        """
        self.is_current_user = is_current_user

    def get_is_current_user(self):
        """Get whether it is current user or not.

        Returns:
            bool: True if it is current user else false.

        """
        return self.is_current_user
     
    def set_comment_id(self, comment_id):
        """Set comment id.
     
        Args:
            comment_id(str): Comment id.
 
        """
        self.comment_id = comment_id

    def get_comment_id(self):
        """Get comment id.
 
        Returns:
            str: Comment id.

        """
        return self.comment_id
  
    def set_contact_id(self, contact_id):
        """Set contact id.
        
        Args: 
            contact_id(str): Contact id.
  
        """
        self.contact_id = contact_id

    def get_contact_id(self):
        """Get contact id.
     
        Returns:
            str: Contact id.
 
        """
        return self.contact_id
   
    def set_contact_name(self, contact_name):
        """Set contact name.
 
        Args:
            contact_name(str): Contact name.

        """
        self.contact_name = contact_name

    def get_contact_name(self):
        """Get contact name.
 
        Returns:
            str: Contact name.

        """
        return self.contact_name

    def set_description(self, description):
        """Set description.
     
        Args:
            description(str): Description.
 
        """
        self.description = description
 
    def get_description(self):
        """Get descritpion.

        Returns:
            str: Description.

        """
        return self.description

    def set_commented_by_id(self, commented_by_id):
        """Set commented by id.

        Args:
            commented_by_id(str): Commented by id.

        """
        self.commented_by_id = commented_by_id
 
    def get_commented_by_id(self):
        """Get commented by id.

        Returns:
            str: Commented by id.
        
        """
        return self.commented_by_id
  
    def set_commented_by(self, commented_by):
        """Set commented by.

        Args:
            commented_by(str): Commented by.

        """
        self.commented_by = commented_by

    def get_commented_by(self):
        """Get commented by.

        Returns: 
            str: Commented by.

        """
        return self.commented_by

    def set_date(self, date):
        """Set date.

        Args: 
            date(str): Date.

        """
        self.date = date

    def get_date(self):
        """Get date.

        Returns: 
            str: Date.
         
        """
        return self.date
   
    def set_date_description(self, date_description):
        """Set date description.
        
        Args: 
            date_description(str): Date description.

        """
        self.date_description = date_description
 
    def get_date_description(self):
        """Get date description.

        Returns:
            str: Date description.
 
        """
        return self.date_description

    def set_time(self, time):
        """Set time.
     
        Args:
            time(str): Time.
        
        """
        self.time = time

    def get_time(self):
        """Get time.

        Returns:
            str: Time.

        """
        return self.time     

    def set_transaction_id(self, transaction_id):
        """Set transaction id.
 
        Args:
            transaction_id(str): Transaction id.

        """
        self.transaction_id = transaction_id
 
    def get_transaction_id(self): 
        """Get transaction id.
 
        Returns:
            str: Transaction id.

        """
        return self.transaction_id

    def set_transaction_type(self, transaction_type):
        """Set transaction type.
         
        Args:
            transaction_type(str): Transaction type.

        """
        self.transaction_type = transaction_type

    def get_transaction_type(self):
        """Get transaction type.
 
        Returns:
            str: Transaction type.

        """
        return self.transaction_type
   
    def set_is_entity_deleted(self, is_entity_deleted):
        """Set whether entity is deleted or not.
 
        Args:  
            is_entity_deleted(bool): True if entity is deleted else False.
      
        """
        self.is_entity_deleted = is_entity_deleted

    def get_is_entity_deleted(self):
        """Get whether entity is deleted or not.

        Returns: 
            bool: True if entity is deleted else False.

        """
        return self.is_entity_deleted
    
    def set_operation_type(self, operation_type):
        """Set operation type.
     
        Args: 
            operatipon_type(str): Operation type.

        """
        self.operation_type = operation_type
 
    def get_operation_type(self):
        """Get operation type.
        
        Returns:
            str: Operation type.
 
        """
        return self.operation_type
   
    def set_comment_type(self, comment_type):
        """Set comment type.

        Args: 
            comment_type(Str): Comment type.

        """  
        self.comment_type = comment_type

    def get_comment_type(self):
        """Get comment type.
     
        Returns:
            str: Comment type.

        """
        return self.comment_type

    def set_estimate_id(self, estimate_id):
        """Set estimate id.
 
        Args:
            estimate_id(str): Estimate id.

        """
        self.estimate_id = estimate_id

    def get_estimate_id(self):
        """Get estimate id.
 
        Returns: 
            str: Estimate id.

        """
        return self.estimate_id

    def set_invoice_id(self, invoice_id):
        """Set invoice id.
        
        Args:
            invoice_id(str): Invoice id.

        """
        self.invoice_id = invoice_id

    def get_invoice_id(self):
        """Get invoice id.

        Returns:
            str: Invoice id.

        """
        return self.invoice_id

    def set_payment_expected_date(self, payment_expected_date):
        """Set payment expected date.
 
        Args: 
            payment_expected_date(str): Payment expected date.

        """
        self.payment_expected_date = payment_expected_date

    def get_payment_expected_date(self):
        """Get payment expected date.

        Returns:
            str: Payment expected date.

        """
        return self.payment_expected_date

    def set_show_comment_to_clients(self, show_comment_to_clients):
        """Set whether to show comment to clients.

        Args:
            show_comment_to_client(bool): True to show comment to 
                clients else False.

        """
        self.show_comment_to_clients = show_comment_to_clients

    def get_show_comment_to_clients(self):
        """Get whether to show comment to clients.

        Returns:
            bool: True to show comment to clients else False.
 
        """
        return self.show_comment_to_clients


    def set_recurring_invoice_id(self, recurring_invoice_id):
        """Set recurring invoice id.
 
        Args: 
            recurring_invoice_id(str): Recurring invoice id.
      
        """ 
        self.recurring_invoice_id = recurring_invoice_id

    def get_recurring_invoice_id(self):
        """Get recurring invoice id.
       
        Returns:
            str: Recurring invoice id.
     
        """
        return self.recurring_invoice_id
  
    def set_creditnote_id(self, creditnote_id):
        """Set creditnote id.

        Args:
            creditnote_id (str): Creditnote id.
 
        """
        self.creditnote_id = creditnote_id
 
    def get_creditnote_id(self):
        """Get creditnote id.
 
        Args:
            str: Creditnote id.

        """
        return self.creditnote_id
   
    def set_expense_id(self, expense_id):
        """Set expense id.

        Args:
            expense_id(str): Expense id.

        """
        self.expense_id = expense_id

    def get_expense_id(self): 
        """Get expense id.
 
        Returns:
            str: Expense id.

        """
        return self.expense_id

    def set_recurring_expense_id(self, recurring_expense_id): 
        """Set recurring expense id.

        Args:
            recurring_expense_id(str): Recurring expense id.

        """
        self.recurring_expense_id = recurring_expense_id

    def get_recurring_expense_id(self):
        """Get recurring expense id.

        Returns:
            str: Recurring expense id.

        """
        return self.recurring_expense_id

    def set_bill_id(self, bill_id):
        """Set bill id.

        Args:
            bill_id(str): Bill id.

        """
        self.bill_id = bill_id

    def get_bill_id(self):
        """Get bill id.

        Returns:
            str: Bill id.

        """
        return self.bill_id

    def set_project_id(self, project_id):
        """Set project id.
       
        Args:
            project_id(str): Project id.

        """
        self.project_id = project_id

    def get_project_id(self):
        """Get project id.

        Returns:
            str: Project id.

        """
        return self.project_id




#$Id$

from books.model.PageContext import PageContext

class ContactPersonList:
    """This class is used to create object for contact person list."""
    def __init__(self):
        """Initialize the parameters for contact person list.""" 
        self.contact_person = []
        self.page_context = PageContext()

    def set_contact_persons(self, contact_person):
        """Set contact persons.
        
        Args:
            contact_person(instance): Contact person object.

        """ 
        self.contact_person.append(contact_person)

    def get_contact_persons(self):
        """Get contact person.
       
        Returns: 
            list: List of contact persons list.
      
        """
        return self.contact_person
  
    def set_page_context(self, page_context):
        """Set page context.
        
        Args:
            page_context(instance): Page_context object.
       
        """
        self.page_context = page_context
 
    def get_page_context(self):
        """Get page context.
        
        Returns:  
            instance: Page context object.

        """
        return self.page_context





#$Id$

from books.model.PageContext import PageContext

class ExpenseList:
    """This class is used to create object for Expenses List."""
    def __init__(self):
        """Initialize parameters for Expenses list object."""
        self.expenses = []
        self.page_context = PageContext()

    def set_expenses(self, expense):
        """Set expenses.

        Args:
            expense(instance): Expense object.

        """
        self.expenses.append(expense)

    def get_expenses(self):
        """Get expenses.

        Returns:
            list of instance: List of expense object.

        """
        return self.expenses

    def set_page_context(self, page_context):
        """Set page context.

        Args:
            page_context(instance): Page context object.
 
        """
        self.page_context = page_context

    def get_page_context(self):
        """Get page context.

        Returns:
            instance: Page context object.

        """
        return self.page_context 



#$Id$

class CustomerPayment:
    """This class is used to create object for customer payments."""
    def __init__(self):
        """Initialize parameters for customer payments."""
        self.customer_id = ''
        self.invoices = []
        self.payment_mode = ''
        self.description = ''
        self.date = ''
        self.reference_number = ''
        self.exchange_rate = 0.0
        self.amount = 0.0
        self.bank_charges = 0.0
        self.tax_account_id = ''
        self.account_id = ''
        self.payment_id = ''
        self.invoice_id = ''
        self.payment_number = ''
        self.invoice_numbers = ''
        self.bcy_amount = 0
        self.unused_amount = 0
        self.bcy_unused_amount = 0
        self.account_name = ''
        self.customer_name = ''
        self.created_time = ''
        self.last_modified_time = ''
        self.tax_account_name = ''
        self.tax_amount_withheld = 0.0
        self.amount_applied = 0.0
   
    def set_customer_id(self, customer_id):
        """Set customer id.
   
        Args:
            customer_id(str): Customer id.

        """
        self.customer_id = customer_id

    def get_customer_id(self):
        """Get customer id.

        Returns:
            str: Customer id.

        """
        return self.customer_id
  
    def set_invoices(self, invoice):
        """Set invoices.

        Args:
            invoice(list) : List of invoice object.

        """
        self.invoices.extend(invoice)
 
    def get_invoices(self):
        """Get invoices.

        Returns:
            list: List of invoices.

        """ 
        return self.invoices

    def set_payment_mode(self, payment_mode):
        """Set mode of payment for the payment received.

        Args:
            payment_mode(str): Mode of payment.

        """
        self.payment_mode = payment_mode

    def get_payment_mode(self):
        """Get mode of payment of the payment received.

        Returns:
            str: Mode of payment.

        """
        return self.payment_mode

    def set_description(self, description):
        """Set description for the customer payment.
 
        Args:
            description(str): Description for the customer payment.

        """
        self.description = description

    def get_description(self):
        """Get description of the customer payment.

        Returns:
            str: Description of the customer payment.
  
        """
        return self.description
   
    def set_date(self, date):
        """Set date at which the payment is made.

        Args:
            date(str): Date at which payment is made.

        """
        self.date = date
 
    def get_date(self):
        """Get date at which payment is made.

        Returns:
            str: Date at which payment is made.

        """
        return self.date

    def set_reference_number(self, reference_number): 
        """Set reference number for the customer payment.

        Args:
            reference_number(str): Reference number for the customer payment.

        """
        self.reference_number = reference_number

    def get_reference_number(self):
        """Get reference number of the customer payment.

        Returns:
            str: Reference number of the customer payment.

        """
        return self.reference_number
   
    def set_exchange_rate(self,  exchange_rate):
        """Set exchange rate for the currency.

        Args: 
            exchange_rate(float): Exchange rate for thee currency.
 
        """
        self.exchange_rate = exchange_rate

    def get_exchange_rate(self):
        """Get exchange rate of the currency.

        Returns:
            float: Exchange rate of the currency.

        """
        return self.exchange_rate

    def set_amount(self, amount):
        """Set payment amount made by the customer.

        Args: 
            amount(float): Payment amount made by the customer.

        """
        self.amount = amount

    def get_amount(self):
        """Get payment amount made by the customer.

        Returns:
            float: Payment amount made by the customer.

        """
        return self.amount
  
    def set_bank_charges(self, bank_charges):
        """Set bank charges incurred.

        Args:
            bank_charges(float): Bank charges incurred.

        """
        self.bank_charges = bank_charges

    def get_bank_charges(self):
        """Get bank charges incurred.

        Returns:
            float: Bank charges incurred.
      
        """
        return self.bank_charges

    def set_tax_account_id(self, tax_account_id):
        """Set id for the tax account incase of withholding tax.

        Args: 
            tax_account_id(str): Id for the tax account.

        """
        self.tax_account_id = tax_account_id

    def get_tax_account_id(self):
        """Get id of the tax account.

        Returns:
            str: Id of the tax account.

        """
        return self.tax_account_id
  
    def set_account_id(self, account_id):
        """Set ID for the cash/ bank account to which the
               payment has to be deposited.

        Args:
            account_id(str): Id for the cash or bank account.

        """
        self.account_id = account_id

    def get_account_id(self):
        """Get ID of the cash/ bank account to which the 
               payment has to be deposited.

        Returns:
            str: Id of the cash or bank account.

        """
        return self.account_id
 
    def set_payment_id(self, payment_id):
        """Set payment id.

        Args:
            payment_id(str): Payment id.

        """
        self.payment_id = payment_id

    def get_payment_id(self):
        """Get payment id.

        Returns:
            str: Payment id.
        
        """
        return self.payment_id

    def set_payment_number(self, payment_number):
        """Set payment number.

        Args:
            payment_number(str): Payment number.

        """
        self.payment_number = payment_number
 
    def get_payment_number(self):
        """Get payment number.
 
        Returns:
            str: Payment number.

        """
        return self.payment_number
  
    def set_invoice_numbers(self, invoice_numbers):
        """Set invoice numbers.

        Args:
            invoice_numbers(str): invoice_numbers

        """
        self.invoice_numbers = invoice_numbers

    def get_invoice_numbers(self):
        """Get invoice numbers.
       
        Returns: 
            str: Invoice numbers

        """
        return self.invoice_numbers
 
    def set_bcy_amount(self, bcy_amount):
        """Set bcy amount.

        Args:
            bcy_amount(int): bcy amount.

        """
        self.bcy_amount = bcy_amount

    def get_bcy_amount(self):
        """Get bcy amount.

        Returns:
            int: bcy amount.

        """
        return self.bcy_amount
   
    def set_unused_amount(self, unused_amount):
        """Set unused amount.

        Args:
            unused_amount(int): Unused amount.

        """
        self.unused_amount = unused_amount
 
    def get_unused_amount(self):
        """Get unused amount.

        Returns:
            int: Unused amount.

        """
        return self.unused_amount
  
    def set_bcy_unused_amount(self, bcy_unused_amount):
        """Set bcy unused amount.
 
        Args:
            bcy_unused_amount(int): bcy unused amount.

        """
        self.bcy_unused_amount = bcy_unused_amount

    def get_bcy_unused_amount(self):
        """Get bcy unused amount.

        Returns:
            int: bcy unused amount.

        """
        return self.bcy_unused_amount
  
    def set_account_name(self, account_name):
        """Set account name.

        Args:
            account_name(str): Account name.

        """
        self.account_name = account_name

    def get_account_name(self):
        """Get account name.

        Returns:
            str: Account name.

        """
        return self.account_name

    def set_customer_name(self, customer_name):
        """Set customer name.

        customer_name(str): Customer name.

        """
        self.customer_name = customer_name
 
    def get_customer_name(self):
        """Get customer name.

        Returns:
            str: Customer name.

        """
        return self.customer_name

    def set_created_time(self, created_time):
        """Set created time.

        Args:
            created_time(str): Created time.

        """
        self.created_time = created_time
    def get_created_time(self):
        """Get created time.
       
        Returns:
            str: Created time.
        """
        return self.created_time
  
    def set_last_modified_time(self, last_modified_time):
        """Set last modified time.

        Args:
            last_modified_time(str): Last modified time.

        """
        self.last_modified_time = last_modified_time

    def get_last_modified_time(self):
        """Get last modified time.

        Returns:
            str: Last modified time.

        """
        return self.last_modified_time

    def set_tax_account_name(self, tax_account_name):
        """Set tax account name.

        Args:
            tax_account_name(str): Tax Account name.
 
        """
        self.tax_account_name = tax_account_name

    def get_tax_account_name(self):
        """Get tax account name.

        Returns:
            str: Tax account name.
 
        """
        return self.tax_account_name

    def set_tax_amount_withheld(self, tax_amount_withheld):
        """Set amount withheld for tax.

        Args:
            tax_amount_withheld(float): Amount withheld for tax.

        """
        self.tax_amount_withheld = tax_amount_withheld

    def get_tax_amount_withheld(self):
        """Get amount withheld for tax.

        Returns:
            float: Amount withheld for tax.

        """
        return self.tax_amount_withheld

    def to_json(self):
        """This method is used to convert customer payment object to json object.

        Returns:
            dict: Dictionary containing json object for customer payments.

        """
        data = {}
        if self.customer_id != '':
            data['customer_id'] = self.customer_id
        if self.invoices:
            data['invoices'] = []
            for value in self.invoices:
                invoice = value.to_json()
                data['invoices'].append(invoice)
        if self.payment_mode != '':
            data['payment_mode'] = self.payment_mode
        if self.description != '':
            data['description'] = self.description
        if self.date != '':
            data['date'] = self.date
        if self.reference_number != '':
            data['reference_number'] = self.reference_number
        if self.exchange_rate > 0:
            data['exchange_rate'] = self.exchange_rate
        if self.amount > 0:
            data['amount'] = self.amount
        if self.bank_charges > 0:
            data['bank_charges'] = self.bank_charges 
        if self.tax_account_id != '':
            data['tax_account_id'] = self.tax_account_id
        if self.account_id != '':
            data['account_id'] = self.account_id
        if self.invoice_id != '':
            data['invoice_id'] = self.invoice_id
        if self.amount_applied > 0:
            data['amount_applied'] = self.amount_applied
        if self.payment_number != '':
            data['payment_number'] = self.payment_number

        return data



#$Id$#

class ExchangeRateList:
    """This class is used to create object for Exchange Rate List."""
  
    def __init__(self):
        """Initialize parameters for exchange rate list."""
        self.exchange_rates = []

    def set_exchange_rates(self, exchange_rate):
        """Set exchange rate.

        Args:
            exchange_rate(instance): Exchange rate.

        """
        self.exchange_rates.append(exchange_rate)

    def get_exchange_rates(self):
        """Get exchange rate.

        Returns:
            list of instance: List of exchange rate object.
 
        """
        return self.exchange_rates



#$Id$#

from books.model.ChartOfAccount import ChartOfAccount
from books.model.ChartOfAccountList import ChartOfAccountList
from books.model.TransactionList import TransactionList
from books.model.Transaction import Transaction
from books.model.PageContext import PageContext

class ChartOfAccountsParser:
    """This class parses the json response for chart of accounts."""

    def get_list(self, resp):
        """This method parses the given response and returns chart of accounts 
            list.

        Args:
            resp(dict): Dictionary containing json object for chart of accounts 
                list.

        Returns: 
            instance: Chart of accounts list object.

        """
        chart_of_accounts_list = ChartOfAccountList()
        for value in resp['chartofaccounts']:
            chart_of_accounts = ChartOfAccount()
            chart_of_accounts.set_account_id(value['account_id'])
            chart_of_accounts.set_account_name(value['account_name'])
            chart_of_accounts.set_account_type(value['account_type'])
            chart_of_accounts.set_is_active(value['is_active'])
            chart_of_accounts.set_is_user_created(value['is_user_created'])
            chart_of_accounts.set_is_involved_in_transaction(value[\
            'is_involved_in_transaction'])
            chart_of_accounts.set_is_system_account(value['is_system_account'])
            chart_of_accounts_list.set_chartofaccounts(chart_of_accounts)
        page_context = resp['page_context']
        page_context_obj = PageContext()
        page_context_obj.set_page(page_context['page'])
        page_context_obj.set_per_page(page_context['per_page'])
        page_context_obj.set_has_more_page(page_context['has_more_page'])
        page_context_obj.set_report_name(page_context['report_name'])
        page_context_obj.set_applied_filter(page_context['applied_filter'])
        page_context_obj.set_sort_column(page_context['sort_column'])
        page_context_obj.set_sort_order(page_context['sort_order'])
        chart_of_accounts_list.set_page_context(page_context_obj)
        return chart_of_accounts_list

    def get_account(self, resp):
        """This method parses the given response and returns chart of 
            accounts object.

        Args:
            resp(dict): Dictionary containing json object for chart of accounts.

        Returns:
            instance: Chart of accounts object.

        """
        chart_of_account = resp['chart_of_account']
        chart_of_account_obj = ChartOfAccount()
        chart_of_account_obj.set_account_id(chart_of_account['account_id'])
        chart_of_account_obj.set_account_name(chart_of_account['account_name']) 
        chart_of_account_obj.set_is_active(chart_of_account['is_active'])
        chart_of_account_obj.set_account_type(chart_of_account['account_type'])
        chart_of_account_obj.set_account_type_formatted(chart_of_account[\
        'account_type_formatted'])
        chart_of_account_obj.set_description(chart_of_account['description'])
        return chart_of_account_obj

    def get_message(self, resp):
        """This method parses the given response and returns string message.

        Args:
            reps(dict): Dictionary containing json object for message.

        Returns:
            str: Success message.

        """ 
        return resp['message']    

    def get_transactions_list(self, resp):
        """This method parses the given response and returns transactions list.

        Args:
            resp(dict): Dictionary containing json object for transactions list.

        Returns:
            instance: Transaction list object.

        """
        transactions_list = TransactionList()
        for value in resp['transactions']:
            transactions = Transaction()
            transactions.set_categorized_transaction_id(value[\
            'categorized_transaction_id'])
            transactions.set_transaction_type(value['transaction_type'])
            transactions.set_transaction_id(value['transaction_id'])
            transactions.set_transaction_date(value['transaction_date'])
            transactions.set_transaction_type_formatted(value[\
            'transaction_type_formatted'])
            transactions.set_account_id(value['account_id']) 
            transactions.set_customer_id(value['customer_id'])
            transactions.set_payee(value['payee'])
            transactions.set_description(value['description'])
            transactions.set_entry_number(value['entry_number'])
            transactions.set_currency_id(value['currency_id'])
            transactions.set_currency_code(value['currency_code'])
            transactions.set_debit_or_credit(value['debit_or_credit'])
            transactions.set_offset_account_name(value['offset_account_name'])
            transactions.set_reference_number(value['reference_number'])
            transactions.set_reconcile_status(value['reconcile_status'])
            transactions.set_debit_amount(value['debit_amount'])
            transactions.set_credit_amount(value['credit_amount'])
            transactions_list.set_transactions(transactions)
        page_context = resp['page_context']
        page_context_obj = PageContext()
        page_context_obj.set_page(page_context['page'])
        page_context_obj.set_per_page(page_context['per_page'])
        page_context_obj.set_has_more_page(page_context['has_more_page'])
        page_context_obj.set_report_name(page_context['report_name'])
        page_context_obj.set_sort_column(page_context['sort_column'])
        page_context_obj.set_sort_order(page_context['sort_order'])
        transactions_list.set_page_context(page_context_obj)
        return transactions_list

       



#$Id$#

from books.model.Expense import Expense
from books.model.ExpenseList import ExpenseList
from books.model.Comment import Comment
from books.model.PageContext import PageContext
from books.model.CommentList import CommentList

class ExpensesParser:
    """This class is used to parse the json for Expenses."""
     
    def get_list(self, resp): 
        """This method parses the given response and returns Expense list 
            object.

        Args:
            resp(dict): Response containing json object for Expenses list.
        
        Returns:
            instance: Expenses list object.

        """
        expenses = resp['expenses']
        expense_list = ExpenseList()
        for value in expenses:
            expense = Expense()
            expense.set_expense_id(value['expense_id'])
            expense.set_date(value['date'])
            expense.set_account_name(value['account_name'])
            expense.set_paid_through_account_name(value[\
            'paid_through_account_name'])
            expense.set_description(value['description'])
            expense.set_currency_id(value['currency_id'])
            expense.set_currency_code(value['currency_code'])
            expense.set_bcy_total(value['bcy_total'])
            expense.set_total(value['total'])
            expense.set_is_billable(value['is_billable'])
            expense.set_reference_number(value['reference_number'])
            expense.set_customer_id(value['customer_id'])
            expense.set_customer_name(value['customer_name'])
            expense.set_vendor_id(value['vendor_id'])
            expense.set_vendor_name(value['vendor_name'])
            expense.set_status(value['status'])
            expense.set_created_time(value['created_time'])
            expense.set_expense_receipt_name(value['expense_receipt_name'])
            expense_list.set_expenses(expense)
        page_context_obj = PageContext()
        page_context = resp['page_context']
        page_context_obj.set_page(page_context['page'])
        page_context_obj.set_per_page(page_context['per_page'])
        page_context_obj.set_has_more_page(page_context['has_more_page'])
        page_context_obj.set_report_name(page_context['report_name'])
        page_context_obj.set_applied_filter(page_context['applied_filter'])
        page_context_obj.set_sort_column(page_context['sort_column'])
        page_context_obj.set_sort_order(page_context['sort_order'])
        expense_list.set_page_context(page_context)

        return expense_list

    def get_expense(self, resp):  
        """This method parses the given response and returns expense object.

        Args:
            resp(dict): Response containing json object for expense.

        Returns:
            instance: Expense object.

        """
        expense = resp['expense']
        expense_obj = Expense()
        expense_obj.set_expense_id(expense['expense_id'])
        expense_obj.set_expense_item_id(expense['expense_item_id'])
        expense_obj.set_account_id(expense['account_id'])
        expense_obj.set_account_name(expense['account_name'])
        expense_obj.set_paid_through_account_id(expense[\
        'paid_through_account_id'])
        expense_obj.set_paid_through_account_name(expense[\
        'paid_through_account_name'])
        expense_obj.set_vendor_id(expense['vendor_id'])
        expense_obj.set_vendor_name(expense['vendor_name'])
        expense_obj.set_date(expense['date'])
        expense_obj.set_tax_id(expense['tax_id'])
        expense_obj.set_tax_name(expense['tax_name'])
        expense_obj.set_tax_percentage(expense['tax_percentage'])
        expense_obj.set_currency_id(expense['currency_id'])
        expense_obj.set_currency_code(expense['currency_code'])
        expense_obj.set_exchange_rate(expense['exchange_rate'])
        expense_obj.set_tax_amount(expense['tax_amount'])
        expense_obj.set_sub_total(expense['sub_total'])
        expense_obj.set_total(expense['total'])
        expense_obj.set_bcy_total(expense['bcy_total'])
        expense_obj.set_amount(expense['amount'])
        expense_obj.set_is_inclusive_tax(expense['is_inclusive_tax'])
        expense_obj.set_reference_number(expense['reference_number'])
        expense_obj.set_description(expense['description'])
        expense_obj.set_is_billable(expense['is_billable'])
        expense_obj.set_customer_id(expense['customer_id'])
        expense_obj.set_customer_name(expense['customer_name'])
        expense_obj.set_expense_receipt_name(expense['expense_receipt_name'])
        expense_obj.set_created_time(expense['created_time'])
        expense_obj.set_last_modified_time(expense['last_modified_time'])
        expense_obj.set_status(expense['status'])
        expense_obj.set_invoice_id(expense['invoice_id'])
        expense_obj.set_invoice_number(expense['invoice_number'])
        expense_obj.set_project_id(expense['project_id'])
        expense_obj.set_project_name(expense['project_name'])
        return expense_obj

    def get_message(self, resp):
        """This method parses the given json string and returns string message.

        Args:
            resp(dict): Response containing json object for success message.

        Returns:
            str: Success message.

        """
        return resp['message']

    def get_comments(self, resp):
        """This method parses the given json string and returns comments list.

        Args:
            resp(dict): Response containing json object for comments.

        Returns:
            instance: Comments list object.

        """
        comments = CommentList()
        for value in resp['comments']:
            comment = Comment()
            comment.set_comment_id(value['comment_id'])
            comment.set_expense_id(value['expense_id'])
            comment.set_description(value['description'])
            comment.set_commented_by_id(value['commented_by_id'])
            comment.set_commented_by(value['commented_by'])
            comment.set_date(value['date'])
            comment.set_date_description(value['date_description'])
            comment.set_time(value['time'])
            comment.set_operation_type(value['operation_type'])
            comment.set_transaction_id(value['transaction_id'])
            comment.set_transaction_type(value['transaction_type'])
            comments.set_comments(comment)
        return comments



#$Id$#

from books.model.Bill import Bill
from books.model.BillList import BillList
from books.model.LineItem import LineItem
from books.model.Address import Address
from books.model.Tax import Tax
from books.model.BillPayment import BillPayment
from books.model.PageContext import PageContext
from books.model.Comment import Comment
from books.model.CommentList import CommentList

class BillsParser:
    """This class is used to parse the json for Bills"""
    
    def get_list(self, resp):
        """This method parses the given response and returns  bill list object.

        Args:
            resp(dict): Response containing json object for bill list.

        Returns: 
            instance: Bill list object.

        """
        bill_list = BillList()
        for value in resp['bills']:
            bill = Bill()
            bill.set_bill_id(value['bill_id'])
            bill.set_vendor_id(value['vendor_id'])
            bill.set_vendor_name(value['vendor_name'])
            bill.set_status(value['status'])
            bill.set_bill_number(value['bill_number'])
            bill.set_reference_number(value['reference_number'])
            bill.set_date(value['date'])
            bill.set_due_date(value['due_date'])
            bill.set_due_days(value['due_days'])
            bill.set_currency_id(value['currency_id'])
            bill.set_currency_code(value['currency_code'])
            bill.set_total(value['total'])
            bill.set_balance(value['balance'])
            bill.set_created_time(value['created_time'])
            bill_list.set_bills(bill)
        page_context_obj = PageContext()
        page_context = resp['page_context']
        page_context_obj.set_page(page_context['page'])
        page_context_obj.set_per_page(page_context['per_page'])
        page_context_obj.set_has_more_page(page_context['has_more_page']) 
        page_context_obj.set_report_name(page_context['report_name'])
        page_context_obj.set_applied_filter(page_context['applied_filter'])
        page_context_obj.set_sort_column(page_context['sort_column'])
        page_context_obj.set_sort_order(page_context['sort_order'])
        bill_list.set_page_context(page_context_obj)
        return bill_list

    def get_bill(self, resp):
        """This method parses the given response and returns bills object.

        Args:
            resp(dict): Response containing json object for bill object.

        Returns:
            instance: Bill object.

        """
        bill = resp['bill']
        bill_obj = Bill()
        bill_obj.set_bill_id(bill['bill_id'])
        bill_obj.set_vendor_id(bill['vendor_id'])
        bill_obj.set_vendor_name(bill['vendor_name'])
        bill_obj.set_unused_credits_payable_amount(bill[\
        'unused_credits_payable_amount'])
        bill_obj.set_status(bill['status'])
        bill_obj.set_bill_number(bill['bill_number'])
        bill_obj.set_date(bill['date'])
        bill_obj.set_due_date(bill['due_date'])
        bill_obj.set_reference_number(bill['reference_number'])
        bill_obj.set_due_by_days(bill['due_by_days'])
        bill_obj.set_due_in_days(bill['due_in_days'])
        bill_obj.set_currency_id(bill['currency_id'])
        bill_obj.set_currency_code(bill['currency_code'])
        bill_obj.set_currency_symbol(bill['currency_symbol'])
        bill_obj.set_price_precision(bill['price_precision'])
        bill_obj.set_exchange_rate(bill['exchange_rate'])
        for value in bill['line_items']:
            line_item = LineItem()
            line_item.set_line_item_id(value['line_item_id'])
            line_item.set_account_id(value['account_id'])
            line_item.set_account_name(value['account_name'])
            line_item.set_description(value['description'])
            line_item.set_bcy_rate(value['bcy_rate'])
            line_item.set_rate(value['rate'])
            line_item.set_quantity(value['quantity'])
            line_item.set_tax_id(value['tax_id'])
            line_item.set_tax_name(value['tax_name'])
            line_item.set_tax_type(value['tax_type'])
            line_item.set_tax_percentage(value['tax_percentage'])
            line_item.set_item_total(value['item_total'])
            line_item.set_item_order(value['item_order'])
            bill_obj.set_line_items(line_item)
        bill_obj.set_sub_total(bill['sub_total'])
        bill_obj.set_tax_total(bill['tax_total'])
        bill_obj.set_total(bill['total'])
        for value in bill['taxes']:
            tax = Tax()
            tax.set_tax_name(value['tax_name'])
            tax.set_tax_amount(value['tax_amount'])
            bill_obj.set_taxes(tax)
        bill_obj.set_payment_made(bill['payment_made'])
        bill_obj.set_balance(bill['balance'])
        billing_address = bill['billing_address']
        billing_address_obj = Address()
        billing_address_obj.set_address(billing_address['address'])
        billing_address_obj.set_city(billing_address['city'])
        billing_address_obj.set_state(billing_address['state'])
        billing_address_obj.set_zip(billing_address['zip'])
        billing_address_obj.set_country(billing_address['country'])
        billing_address_obj.set_fax(billing_address['fax'])
        bill_obj.set_billing_address(billing_address_obj)
        for value in bill['payments']:
            payments = BillPayment()
            payments.set_payment_id(value['payment_id'])
            payments.set_bill_id(value['bill_id'])
            payments.set_bill_payment_id(value['bill_payment_id'])
            payments.set_payment_mode(value['payment_mode'])
            payments.set_description(value['description'])
            payments.set_date(value['date'])
            payments.set_reference_number(value['reference_number'])
            payments.set_exchange_rate(value['exchange_rate'])
            payments.set_amount(value['amount'])
            payments.set_paid_through_account_id(value[\
            'paid_through_account_id'])
            payments.set_paid_through_account_name(value[\
            'paid_through_account_name'])
            payments.set_is_single_bill_payment(value[\
            'is_single_bill_payment'])
            billing_address_obj.set_payments(payments)
        bill_obj.set_created_time(bill['created_time'])
        bill_obj.set_last_modified_time(bill['last_modified_time'])
        bill_obj.set_reference_id(bill['reference_id'])
        bill_obj.set_notes(bill['notes'])
        bill_obj.set_terms(bill['terms'])
        bill_obj.set_attachment_name(bill['attachment_name'])
        return bill_obj

    def get_message(self, resp): 
        """This method parses the given response and returns string message.

        Args:
            resp(dict): Response containing json object for success message.
 
        Returns:
            str: Success message.

        """
        return resp['message']
 
    def get_payments_list(self, resp):
        """This method parses the given response and returns payments list 
            object.

        Args:
            resp(dict): Response containing json object for payments list.

        Returns:
            list of instance: List of payments object.

        """
        payments = []
        for value in resp['payments']:
            payment = BillPayment()
            payment.set_payment_id(value['payment_id'])
            payment.set_bill_id(value['bill_id'])
            payment.set_bill_payment_id(value['bill_payment_id'])
            payment.set_vendor_id(value['vendor_id'])
            payment.set_vendor_name(value['vendor_name'])
            payment.set_payment_mode(value['payment_mode'])
            payment.set_description(value['description'])
            payment.set_date(value['date'])
            payment.set_reference_number(value['reference_number'])
            payment.set_exchange_rate(value['exchange_rate'])
            payment.set_amount(value['amount'])
            payment.set_paid_through(value['paid_through'])
            payment.set_is_single_bill_payment(value['is_single_bill_payment'])
            payments.append(payment)
        return payments

    def get_comments(self, resp):
        comments = CommentList()
        for value in resp['comments']:
            comment = Comment()
            comment.set_comment_id(value['comment_id'])
            comment.set_bill_id(value['bill_id'])
            comment.set_description(value['description'])
            comment.set_commented_by_id(value['commented_by_id'])
            comment.set_commented_by(value['commented_by'])
            comment.set_comment_type(value['comment_type'])
            comment.set_date(value['date'])
            comment.set_date_description(value['date_description'])
            comment.set_time(value['time'])
            comment.set_operation_type(value['operation_type'])
            comment.set_transaction_id(value['transaction_id'])
            comment.set_transaction_type(value['transaction_type'])
            comments.set_comments(comment)
        return comments

    def get_comment(self, resp):
        comment = resp['comment']
        comment_obj = Comment()
        comment_obj.set_comment_id(comment['comment_id'])
        comment_obj.set_bill_id(comment['bill_id'])
        comment_obj.set_description(comment['description']) 
        comment_obj.set_commented_by_id(comment['commented_by_id'])
        comment_obj.set_commented_by(comment['commented_by'])
        comment_obj.set_comment_type(comment['comment_type'])
        comment_obj.set_date(comment['date'])
        comment_obj.set_date_description(comment['date_description'])
        comment_obj.set_time(comment['time'])
        comment_obj.set_comment_type(comment['comment_type'])
        return comment_obj




#$Id$

class EmailTemplate:
    """This class is used to create object for email templates."""
    def __init__(self):
        """Initialize parameters for email templates."""
        self.selected = None
        self.name = ''
        self.email_template_id = ''
   
    def set_selected(self, selected):
        """Set whether to select or not.

        Args:
            selected(bool): True to select else False.

        """
        self.selected = selected
 
    def get_selected(self):
        """Get whether to select or not.

        Returns:
            bool: True to select else False.

        """
        return self.selected
 
    def set_name(self, name):
        """Set name.

        Args:
            name(str): Name.

        """
        self.name = name

    def get_name(self):
        """Get name.

        Returns:
            str: Name.

        """
        return self.name

    def set_email_template_id(self, email_template_id):
        """Set email template id.

        Args: 
            email_template_id(str): Email template id.

        """
        self.email_template_id = email_template_id

    def get_email_template_id(self):
        """Get email template id.

        Returns:
            str: Email template id.

        """
        return self.email_template_id

   



#$Id$

class ToContact:
    """This class is used to create object for to Contacts."""
    def __init__(self):
        """Initialize parameters for to contacts."""
        self.first_name = ''
        self.selected = None
        self.phone = ''
        self.email = ''
        self.last_name = ''
        self.salutation = ''
        self.contact_person_id = ''
        self.mobile = ''

    def set_first_name(self, first_name):
        """Set first name.
  
        Args:
            first_name(str): First name. 
 
        """
        self.first_name = first_name

    def get_first_name(self):
        """Get first name.
     
        Returns:
            str: First name.

        """
        return self.first_name
  
    def set_selected(self, selected):
        """Set selected.
          
        Args:
            selected(bool): Selected.
 
        """
        self.selected = selected

    def get_selected(self):
        """Get selected.
        
        Returns:
            bool: Selected.
        
        """
        return self.selected

    def set_phone(self, phone): 
        """Set phone.
          
        Args:
            phone(str): Phone.
 
        """
        self.phone = phone

    def get_phone(self):
        """Get phone.
 
        Returns:
            str: Phone.

        """
        return self.phone

    def set_email(self, email):
        """Set email.
 
        Args: 
            email(str): Email.
 
        """
        self.email = email

    def get_email(self):
        """Get email.
 
        Returns:
            str: Email.

        """
        return self.email
  
    def set_last_name(self, last_name):
        """Set last name.
        
        Args:
            last_name(str): Last name.

        """
        self.last_name = last_name

    def get_last_name(self):
        """Get last name.

        Returns:
            str: Last name.

        """
        return self.last_name
  
    def set_salutation(self, salutation):
        """Set salutation.
 
        Args:
            salutation(str): Salutation.
    
        """        
        self.salutation = salutation

    def get_salutation(self):
        """Get salutation.
         
        Returns:
            str: Salutation.
        
        """
        return self.salutation
  
    def set_contact_person_id(self, contact_person_id):
        """Set contact person id.
      
        Args:
            contact_person_id(str): Contact person id.

        """
        self.contact_person_id = contact_person_id

    def get_contact_person_id(self):
        """Get person id.
 
        Returns:
            str: Contact person id.

        """
        return self.contact_person_id

    def set_mobile(self, mobile):
        """Set mobile.
  
        Args:
            mobile(str): Mobile.

        """
        self.mobile = mobile

    def get_mobile(self):
        """Get mobile.
  
        Returns:
            str: Mobile.

        """
        return self.mobile

  


